@@ -6,18 +6,18 @@ OC.L10N.register(
     "AppAPI ExApp notifier" : "Powiadomienie AppAPI ExApp",
     "AppAPI" : "AppAPI",
     "Nextcloud AppAPI" : "AppAPI Nextcloud",
-    "Admin options saved" : "Opcje administracyjne zostały zapisane",
-    "Failed to save admin options" : "Nie udało się zapisać opcji administratora",
     "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Projekt AppAPI to ekscytująca inicjatywa, której celem jest zrewolucjonizowanie sposobu tworzenia aplikacji dla Nextcloud.",
     "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Upłynął limit czasu procesu inicjalizacji ExApp, po którym AppAPI oznaczy go jako zakończony niepowodzeniem",
     "This settings changes are reflected only for newly created containers" : "Zmiany tych ustawień zostaną odzwierciedlone tylko w przypadku nowo utworzonych kontenerów",
+    "Admin options saved" : "Opcje administracyjne zostały zapisane",
+    "Failed to save admin options" : "Nie udało się zapisać opcji administratora",
     "Cancel" : "Anuluj",
     "Delete" : "Usuń",
-    "Failed to save admin options. Check the logs" : "Nie udało się zapisać opcji administratora. Sprawdź dzienniki",
-    "Password confirmation failed" : "Potwierdzenie hasła nie powiodło się",
     "Default" : "Domyślny",
     "Set as default" : "Ustaw jako domyślny",
     "Edit" : "Edycja",
+    "Failed to save admin options. Check the logs" : "Nie udało się zapisać opcji administratora. Sprawdź dzienniki",
+    "Password confirmation failed" : "Potwierdzenie hasła nie powiodło się",
     "Name" : "Nazwa",
     "Protocol" : "Protokół",
     "Host" : "Host",
@@ -27,21 +27,15 @@ OC.L10N.register(
     "Compute device" : "Urządzenie obliczeniowe",
     "Additional options" : "Dodatkowe opcje",
     "Verify connection" : "Sprawdź połączenie",
-    "Enabled" : "Włączone",
     "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI spróbuje zainstalować mały szkielet ExApp, aby sprawdzić, czy demon jest poprawnie skonfigurowany i czy etapy wdrażania zostały wykonane.",
     "More info" : "Więcej informacji",
-    "Remove" : "Usuń",
-    "From" : "Od",
-    "To" : "Do",
-    "Add" : "Dodaj",
-    "Hostname to access ExApps" : "Nazwa hosta umożliwiająca dostęp do ExApps",
-    "Daemon with this name already exists" : "Demon o tej nazwie już istnieje",
-    "AppAPI Docker Socket Proxy authentication password" : "Hasło uwierzytelniające AppAPI Docker Socket Proxy",
+    "Enabled" : "Włączone",
     "Display name" : "Wyświetlana nazwa",
     "Deployment method" : "Metoda wdrażania",
     "Select daemon deploy method" : "Wybierz metodę wdrażania demona",
-    "Password must be at least 12 characters long" : "Hasło musi mieć co najmniej 12 znaków",
-    "Disabled" : "Wyłączone",
+    "Network" : "Sieć",
+    "Docker network name" : "Nazwa sieci Dockera",
+    "AppAPI Docker Socket Proxy authentication password" : "Hasło uwierzytelniające AppAPI Docker Socket Proxy",
     "Additional option" : "Opcja dodatkowa",
     "Add additional option" : "Dodaj dodatkową opcję",
     "Option key is required" : "Wymagany jest klucz opcji",
@@ -51,9 +45,14 @@ OC.L10N.register(
     "Save" : "Zapisz",
     "Register" : "Zarejestruj się",
     "Check connection" : "Sprawdź połączenie",
+    "Hostname to access ExApps" : "Nazwa hosta umożliwiająca dostęp do ExApps",
+    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nazwa hosta lub ścieżka dostępu do demona Docker (np. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
+    "Daemon with this name already exists" : "Demon o tej nazwie już istnieje",
+    "Password must be at least 12 characters long" : "Hasło musi mieć co najmniej 12 znaków",
+    "With https enabled network is set to host" : "Przy włączonym https sieć jest ustawiona na host",
     "External Apps" : "Aplikacje zewnętrzne",
-    "{license}-licensed" : "na licencji {license}",
     "Update to {version}" : "Zaktualizuj do {version}",
+    "Remove" : "Usuń",
     "Delete data on remove" : "Usuń dane przy usuwaniu",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej minimalnej wersji Nextcloud. W przyszłości będzie to błąd.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej maksymalnej wersji Nextcloud. W przyszłości będzie to błąd.",
@@ -65,6 +64,7 @@ OC.L10N.register(
     "Admin documentation" : "Dokumentacja administratora",
     "Developer documentation" : "Dokumentacja dewelopera",
     "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ta aplikacja nie jest zarejestrowana w AppStore. Brak dodatkowych informacji. Dozwolone są tylko akcje włączania/wyłączania i usuwania.",
+    "{license}-licensed" : "na licencji {license}",
     "This app is supported via your current Nextcloud subscription." : "Ta aplikacja jest obsługiwana za pośrednictwem bieżącej subskrypcji Nextcloud.",
     "Supported" : "Wspierany",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Polecane aplikacje są tworzone przez społeczność. Oferują główną funkcjonalność i są gotowe do użycia w produkcji.",
@@ -82,15 +82,11 @@ OC.L10N.register(
     "_Update_::_Update all_" : ["Zaktualizuj","Zaktualizuj","Zaktualizuj","Zaktualizuj wszystko"],
     "Type" : "Rodzaj",
     "Display Name" : "Wyświetlana nazwa",
-    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nazwa hosta lub ścieżka dostępu do demona Docker (np. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
-    "With https enabled network is set to host" : "Przy włączonym https sieć jest ustawiona na host",
-    "Network" : "Sieć",
-    "Docker network name" : "Nazwa sieci Dockera",
-    "by {author}\n{license}" : "wykonane przez {author}\n{license}",
     "Your apps" : "Twoje aplikacje",
     "Documentation" : "Dokumentacja",
     "Details" : "Szczegóły",
     "Changelog" : "Dziennik zmian",
+    "by {author}\n{license}" : "wykonane przez {author}\n{license}",
     "Active apps" : "Aktywne aplikacje",
     "Disabled apps" : "Wyłączone aplikacje",
     "Updates" : "Aktualizacje",
@@ -101,7 +97,7 @@ OC.L10N.register(
     "Deploy and Enable" : "Wdróż i włącz",
     "Enable" : "Włącz",
     "Disable" : "Wyłącz",
-    "Allow untested app" : "Zezwalaj na nietestowane aplikacje",
+    "Allow untested app" : "Zezwól na nietestowane aplikacje",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta aplikacja jest niezgodna z wersją Nextcloud. Przy dalszej kontynuacji, możesz pozwolić na zainstalowanie tej aplikacji. Pamiętaj, że aplikacja może nie działać zgodnie z oczekiwaniami.",
     "Your ExApps" : "Twoje ExApps",
     "An error occurred during the request. Unable to proceed." : "Wystąpił błąd podczas żądania. Nie można kontynuować.",
