@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Teams",
     "You created the team {circle}" : "Sie haben das Team {circle} erstellt",
     "{author} created the team {circle}" : "{author} hat das Team {circle} erstellt",
     "You deleted {circle}" : "Sie haben {circle} gelöscht",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} hat eine Anfrage gestellt in {circle} aufgenommen zu werden",
     "You are the new owner of {circle}" : "Sie sind der neue Eigentümer von {circle}",
     "{member} is the new owner of {circle}" : "{member} ist der neue Eigentümer von {circle}",
+    "Teams" : "Teams",
     "On events happening in a <strong>team</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Team</strong>, in dem Sie Mitglied sind",
     "Any important event in a <strong>team</strong> you are moderating" : "Jeder wichtige Termin in einem <strong>Team</strong>, das Sie moderieren",
     "On global events happening in any <strong>team</strong>" : "Bei globalen Ereignissen, in einem beliebigen <strong>Team</strong>",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Contact" : "Kontakt",
     "Team" : "Team",
     "Nextcloud App" : "Nextcloud-App",
+    "Teams App" : "Teams-App",
+    "Admin Command Line" : "Administrations-Befehlszeile",
     "Member" : "Mitglied",
     "Moderator" : "Moderator",
     "Admin" : "Administration",
@@ -104,12 +106,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Initialisierung der Kreise-App",
     "Fresh installation status" : "Aktueller Initialisierungsstatus",
     "Building Local Database" : "Lokale Datenbank wird erstellt",
-    "Testing Basic Circle Creation" : "Testen der grundlegenden Kreiserstellung",
+    "Testing Basic Team Creation" : "Testen der grundlegenden Teamerstellung",
     "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
     "Show all teams" : "Alle Teams anzeigen",
     "Create a new team" : "Ein neues Team erstellen",
     "Files" : "Dateien",
-    "This feature is not available for personal circles" : "Diese Funktion steht für persönliche Kreise nicht zur Verfügung",
+    "This feature is not available for personal teams" : "Diese Funktion steht für persönliche Teams nicht zur Verfügung",
     "The team is not federated" : "Das Team ist nicht federiert",
     "You cannot join this team" : "Du kannst diesem Team nicht beitreten",
     "This member is not a moderator" : "Dieses Mitglied ist kein Moderator",
@@ -117,10 +119,10 @@ OC.L10N.register(
     "This member does not exist" : "Dieses Mitglied existiert nicht",
     "This member is the owner of the team" : "Dieses Mitglied ist der Besitzer des Teams",
     "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
-    "You are already a member of this circle" : "Sie sind bereits Mitglied dieses Kreises",
-    "You have been blocked from this circle" : "Sie wurden für diesen Kreis blockiert",
-    "The account is already a member of this circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
-    "The account has already been invited into this circle" : "Dieses Konto wurde bereits zu diesem Kreis eingeladen.",
+    "You are already a member of this team" : "Sie sind bereits Mitglied dieses Teams",
+    "You have been blocked from this team" : "Sie wurden für dieses Team blockiert",
+    "The account is already a member of this team" : "Dieses Konto ist bereits Mitglied dieses Teams",
+    "The account has already been invited into this team" : "Dieses Konto wurde bereits zu diesem Team eingeladen",
     "%s (Team owned by %s)" : "%s (Team im Besitz von %s)",
     "You are now a member of the Team \"%2$s\"" : "Sie sind jetzt Mitglied des Teams \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Sie wurden von %1$s zum Team \"%2$s\" eingeladen",
@@ -141,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einigen Inhalt mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
     "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit Ihnen geteilt wurde.",
     "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
+    "Federated Teams" : "Federated-Teams",
     "This item is already shared with this team" : "Dieses Element wurde bereits mit diesem Team geteilt",
     "Bring cloud-users closer together." : "Bringen Sie Cloudnutzer näher zueinander.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Mittels Teams können Personen ihre eigenen Gruppen mit Personen/Kollegen/Freunden erstellen.\nDiese Personengruppen können dann von jeder anderen App zum Teilen verwendet werden.",
+    "Unable to update federated teams config" : "Die Einstellungen der Federated-Teams können nicht aktualisiert werden",
+    "Invalid URL format. Please provide a valid URL." : "Ungültiges URL-Format. Bitte eine gültige URL eingeben.",
+    "Changed frontal cloud URL" : "Frontal-Cloud-URL geändert",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Federation ermöglicht Teams mit anderen vertrauenswürdigen Servern zu teilen und sie instanzübergreifend auffindbar zu machen.",
+    "Enable federated teams" : "Federated-Teams aktivieren",
+    "Frontal URL" : "Frontal-URL",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "Die öffentliche URL, die von anderen Instanzen verwendet wird, um Ihre Teams zu entdecken und eine Verbindung zu ihnen herzustellen.",
     "Failed to load teams" : "Teams konnten nicht geladen werden",
     "Try again" : "Erneut versuchen",
     "No teams found" : "Keine Teams gefunden",
@@ -156,11 +167,6 @@ OC.L10N.register(
     "Name" : "Name",
     "Size" : "Größe",
     "Modified" : "Geändert",
-    "Teams' files" : "Team-Dateien",
-    "Select team to filter by" : "Team auswählen, nach dem gefiltert werden soll",
-    "Please select teams to filter by" : "Bitte wählen Sie Teams, nach denen gefiltert werden soll",
-    "No files found for the selected teams" : "Keine Dateien für die ausgewählten Teams gefunden",
-    "Shared to Circles" : "Geteilt mit Kreisen",
-    "Circle" : "Kreis"
+    "Shared to Circles" : "Geteilt mit Kreisen"
 },
 "nplurals=2; plural=(n != 1);");
