@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Foirne",
     "You created the team {circle}" : "Chruthaigh tú an fhoireann {circle}",
     "{author} created the team {circle}" : "Chruthaigh {author} an fhoireann {circle}",
     "You deleted {circle}" : "Scrios tú {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "Sheol {member} iarratas chun páirt a ghlacadh i {circle}",
     "You are the new owner of {circle}" : "Is úinéir nua thú ar {circle}",
     "{member} is the new owner of {circle}" : "Is é {member} úinéir nua {circle}",
+    "Teams" : "Foirne",
     "On events happening in a <strong>team</strong> of which you are a member" : "Ar imeachtaí atá ar siúl i  <strong>bhfoireann</strong>a bhfuil tú i do bhall di",
     "Any important event in a <strong>team</strong> you are moderating" : "Imeacht thábhachtach ar bith i <strong>bhfoireann</strong> a bhfuil tú ag modhnú ",
     "On global events happening in any <strong>team</strong>" : "Ar imeachtaí domhanda ag tarlú in aon <strong>1fhoireann</strong>",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Contact" : "Teagmháil",
     "Team" : "Foireann",
     "Nextcloud App" : "Aip Nextcloud",
+    "Teams App" : "Aip Foirne",
+    "Admin Command Line" : "Líne Ordaithe Riarthóra",
     "Member" : "Ball",
     "Moderator" : "Modhnóir",
     "Admin" : "Riarachán",
@@ -104,12 +106,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Ciorcail Aip Tosaigh",
     "Fresh installation status" : "Stádas suiteála úr",
     "Building Local Database" : "Bunachar Sonraí Áitiúil a Thógáil",
-    "Testing Basic Circle Creation" : "Cruthú Bunúsach Ciorcail a Thástáil",
+    "Testing Basic Team Creation" : "Tástáil ar Chruthú Foirne Bunúsach",
     "Adding local users and moderators" : "Ag cur úsáideoirí áitiúla agus modhnóirí leis",
     "Show all teams" : "Taispeáin gach foireann",
     "Create a new team" : "Cruthaigh foireann nua",
     "Files" : "Comhaid",
-    "This feature is not available for personal circles" : "Níl an ghné seo ar fáil do chiorcail phearsanta",
+    "This feature is not available for personal teams" : "Níl an ghné seo ar fáil do fhoirne pearsanta",
     "The team is not federated" : "Níl an fhoireann cónaidhmthe",
     "You cannot join this team" : "Ní féidir leat dul isteach san fhoireann seo",
     "This member is not a moderator" : "Ní modhnóir é an ball seo",
@@ -117,10 +119,10 @@ OC.L10N.register(
     "This member does not exist" : "Níl an ball seo ann",
     "This member is the owner of the team" : "Is é an ball seo úinéir na foirne",
     "Level cannot be changed for this type of member" : "Ní féidir an leibhéal a athrú don chineál seo ball",
-    "You are already a member of this circle" : "Tá tú i do bhall den chiorcal seo cheana féin",
-    "You have been blocked from this circle" : "Cuireadh bac ort ón gciorcal seo",
-    "The account is already a member of this circle" : "Tá an cuntas ina bhall den chiorcal seo cheana féin",
-    "The account has already been invited into this circle" : "Tugadh cuireadh don chuntas sa chiorcal seo cheana féin",
+    "You are already a member of this team" : "Is ball den fhoireann seo thú cheana féin",
+    "You have been blocked from this team" : "Tá bac curtha ort ón bhfoireann seo",
+    "The account is already a member of this team" : "Tá an cuntas ina bhall den fhoireann seo cheana féin",
+    "The account has already been invited into this team" : "Tá cuireadh tugtha don chuntas isteach sa fhoireann seo cheana féin",
     "%s (Team owned by %s)" : "%s (Foireann faoi úinéireacht %s)",
     "You are now a member of the Team \"%2$s\"" : "Tá tú i do bhall den Fhoireann anois \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Thug%1$s cuireadh duit dul isteach san Fhoireann \"%2$s\"",
@@ -141,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "Roinn %1$s roinnt ábhair leat. Ba cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.",
     "Password to access content shared with you by %1$s" : "Pasfhocal chun rochtain a fháil ar ábhar atá roinnte leat faoi %1$s",
     "Password to access content" : "Pasfhocal chun rochtain a fháil ar ábhar",
+    "Federated Teams" : "Foirne Cónaidhme",
     "This item is already shared with this team" : "Tá an mhír seo roinnte leis an bhfoireann seo cheana féin",
     "Bring cloud-users closer together." : "Tabhair na scamall-úsáideoirí níos gaire dá chéile.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Ligeann foirne do dhaoine a ngrúpaí daoine/comhghleacaithe/cairde féin a chruthú.\nIs féidir leis na grúpaí daoine sin a úsáid ansin ag aon aip eile chun críche comhroinnte.",
+    "Unable to update federated teams config" : "Ní féidir cumraíocht na bhfoirne cónaidhme a nuashonrú",
+    "Invalid URL format. Please provide a valid URL." : "Formáid URL neamhbhailí. Cuir URL bailí ar fáil le do thoil.",
+    "Changed frontal cloud URL" : "URL scamall tosaigh athraithe",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Le Cónaidhm, is féidir leat foirne a roinnt le freastalaithe iontaofa eile agus iad a dhéanamh infheicthe ar fud cásanna.",
+    "Enable federated teams" : "Cumasaigh foirne cónaidhme",
+    "Frontal URL" : "URL Tosaigh",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "An URL poiblí a úsáideann cásanna eile chun do fhoirne a aimsiú agus ceangal leo.",
     "Failed to load teams" : "Theip ar fhoirne a lódáil",
     "Try again" : "Déan iarracht arís",
     "No teams found" : "Níor aimsíodh foirne",
@@ -156,11 +167,6 @@ OC.L10N.register(
     "Name" : "Ainm",
     "Size" : "Méid",
     "Modified" : "Athraithe",
-    "Teams' files" : "Comhaid na bhfoirne",
-    "Select team to filter by" : "Roghnaigh foireann le scagadh de réir",
-    "Please select teams to filter by" : "Roghnaigh foirne lena scagadh le do thoil",
-    "No files found for the selected teams" : "Níor aimsíodh aon chomhaid do na foirne roghnaithe",
-    "Shared to Circles" : "Roinnte go Ciorcail",
-    "Circle" : "Ciorcal"
+    "Shared to Circles" : "Roinnte go Ciorcail"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
