@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Takımlar",
     "You created the team {circle}" : "{circle} takımını eklediniz",
     "{author} created the team {circle}" : "{author}, {circle} takımını ekledi",
     "You deleted {circle}" : "{circle} takımını sildiniz",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} üyesi {circle} takımına katılma isteği gönderdi",
     "You are the new owner of {circle}" : "Artık {circle} takımının sahibisiniz",
     "{member} is the new owner of {circle}" : "{member}, artık {circle} takımının sahibi",
+    "Teams" : "Takımlar",
     "On events happening in a <strong>team</strong> of which you are a member" : "Üyesi olduğunuz bir <strong>takımdaki</strong> olaylarda",
     "Any important event in a <strong>team</strong> you are moderating" : "Sorumlusu olduğunuz bir <strong>takımdaki</strong> önemli olaylarda",
     "On global events happening in any <strong>team</strong>" : "Herhangi bir <strong>takımdaki</strong> genel olaylarda",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Contact" : "Kişi",
     "Team" : "Takım",
     "Nextcloud App" : "Nextcloud uygulaması",
+    "Teams App" : "Takımlar uygulaması",
+    "Admin Command Line" : "Yönetici komut satırı",
     "Member" : "Üye",
     "Moderator" : "Sorumlu",
     "Admin" : "Yönetici",
@@ -104,12 +106,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Takımlar uygulaması başlatılıyor",
     "Fresh installation status" : "Yeni kurulum durumu",
     "Building Local Database" : "Yerel veri tabanı oluşturuluyor",
-    "Testing Basic Circle Creation" : "Temel takım oluşturma sınanıyor",
+    "Testing Basic Team Creation" : "Temel takım oluşturma sınanıyor",
     "Adding local users and moderators" : "Yerel kullanıcılar ve sorumlular ekleniyor",
     "Show all teams" : "Tüm takımları görüntüle",
     "Create a new team" : "Yeni takım ekle",
     "Files" : "Dosyalar",
-    "This feature is not available for personal circles" : "Bu özellik kişisel takımlarda kullanılamaz",
+    "This feature is not available for personal teams" : "Bu özellik kişisel takımlarda kullanılamaz",
     "The team is not federated" : "Takım birleşik değil",
     "You cannot join this team" : "Bu takıma katılamazsınız",
     "This member is not a moderator" : "Bu üye bir sorumlu değil",
@@ -117,10 +119,10 @@ OC.L10N.register(
     "This member does not exist" : "Bu üye bulunamadı",
     "This member is the owner of the team" : "Bu üye takımın sahibi",
     "Level cannot be changed for this type of member" : "Bu üye türünün düzeyi değiştirilemez",
-    "You are already a member of this circle" : "Zaten bu takımın bir üyesisiniz",
-    "You have been blocked from this circle" : "Bu takımda engellenmişsiniz",
-    "The account is already a member of this circle" : "Hesap zaten bu takımın bir üyesi",
-    "The account has already been invited into this circle" : "Hesap zaten bu takıma katılması için davet edilmiş",
+    "You are already a member of this team" : "Zaten bu takımın bir üyesisiniz",
+    "You have been blocked from this team" : "Bu takımda engellenmişsiniz",
+    "The account is already a member of this team" : "Hesap zaten bu takımın bir üyesi",
+    "The account has already been invited into this team" : "Hesap zaten bu takıma katılması için davet edilmiş",
     "%s (Team owned by %s)" : "%s (Takım sahibi %s)",
     "You are now a member of the Team \"%2$s\"" : "Artık \"%2$s\" takımının üyesisiniz",
     "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s tarafından \"%2$s\" takımına davet edildiniz",
@@ -144,6 +146,7 @@ OC.L10N.register(
     "This item is already shared with this team" : "Bu öge zaten bu takım ile paylaşılmış",
     "Bring cloud-users closer together." : "Bulut kullanıcılarını bir araya getirir.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Takımlar, kişilerin kendi kişi/iş arkadaşı/arkadaş gruplarını oluşturmasını sağlar.\nBu kişi grupları başka uygulamalar tarafından paylaşım amacıyla kullanılabilir.",
+    "https://…" : "https://…",
     "Failed to load teams" : "Takımlar yüklenemedi",
     "Try again" : "Yeniden dene",
     "No teams found" : "Herhangi bir takım bulunamadı",
@@ -156,11 +159,6 @@ OC.L10N.register(
     "Name" : "Ad",
     "Size" : "Boyut",
     "Modified" : "Değiştirilme",
-    "Teams' files" : "Takımların dosyaları",
-    "Select team to filter by" : "Süzülecek takımı seçin",
-    "Please select teams to filter by" : "Lütfen süzülecek takımları seçin",
-    "No files found for the selected teams" : "Seçilmiş takımlara uyan bir dosya bulunamadı",
-    "Shared to Circles" : "Takımlarla paylaşıldı",
-    "Circle" : "Takım"
+    "Shared to Circles" : "Takımlarla paylaşıldı"
 },
 "nplurals=2; plural=(n > 1);");
