@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Презареждане на текущата директория",
     "Go to the \"{dir}\" directory" : "Отидете в директорията \"{dir}\"",
     "Current directory path" : "Път на текущата директория",
+    "Share" : "Споделяне",
     "Your have used your space quota and cannot upload files anymore" : "Използвали сте квотата си за пространство и вече не можете да качвате файлове",
     "You do not have permission to upload or create files here." : "Нямате разрешение да качвате или създавате файлове тук.",
     "Drag and drop files here to upload" : "Плъзнете и пуснете файлове тук, за да ги качите",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Тази точка е недостъпна",
     "Another entry with the same name already exists." : "Вече съществува друг запис със същото име.",
     "Invalid filename." : "Невалидно име на файл.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Преименуван \"{oldName}\" на \"{newName}\"",
     "Rename file" : "Преименуване на файл",
     "Folder" : "Папка",
     "Unknown file type" : "Неизвестен тип файл",
@@ -102,12 +102,23 @@ OC.L10N.register(
     "{ext} text" : "{ext} текст",
     "Pending" : "Чакащо",
     "Unknown date" : "Неизвестна дата",
-    "Clear filter" : "Изчстиване на филтър",
-    "Modified" : "Промяна",
-    "Search everywhere" : "Търси навсякъде",
-    "Type" : "Тип",
     "Active filters" : "Актижни филтри",
     "Remove filter" : "Премахни филтър",
+    "Today" : "Днес",
+    "Last 7 days" : "Последни 7 дни",
+    "Last 30 days" : "Последните 30 дни",
+    "This year ({year})" : "Тази година ({year})",
+    "Last year ({year})" : "Миналата година ({year})",
+    "Search everywhere" : "Търси навсякъде",
+    "Documents" : "Документи",
+    "Spreadsheets" : "Електронни таблици",
+    "Presentations" : "Презентации",
+    "PDFs" : "PDF-и",
+    "Folders" : "Папки",
+    "Audio" : "Аудио",
+    "Images" : "Изображения",
+    "Videos" : "Видеа",
+    "Filters" : "Филтри",
     "Appearance" : "Изглед",
     "Show hidden files" : "Показвай и скрити файлове",
     "Show file type column" : "Показване на колона тип файл",
@@ -136,7 +147,6 @@ OC.L10N.register(
     "Go right in grid" : "Отидете дясно на мрежата",
     "View" : "Изглед",
     "Toggle grid view" : "Превключи решетъчния изглед",
-    "Open file sidebar" : "Отворете страничната лента на файла",
     "Show those shortcuts" : "Показване тези преки пътища",
     "Warnings" : "Предупреждения",
     "Warn before changing a file extension" : "Предупреждение преди промяна на файлово разширение",
@@ -150,6 +160,7 @@ OC.L10N.register(
     "Name" : "Име",
     "File type" : "Тип файл",
     "Size" : "Размер",
+    "Modified" : "Промяна",
     "{displayName}: failed on some elements" : "{displayName}: неуспешно за някои елементи",
     "{displayName}: done" : "{displayName}: готово",
     "{displayName}: failed" : "{displayName}: неуспешно",
@@ -164,6 +175,7 @@ OC.L10N.register(
     "Search here …" : "Търсете тук...",
     "Search scope options" : "Опции за обхват на търсене",
     "Search here" : "Търсете тук",
+    "Owner" : "Създател",
     "{usedQuotaByte} used" : "{usedQuotaByte} използвано",
     "{used} of {quota} used" : "{used} от {quota} използвани",
     "{relative}% used" : "{relative}% използвано",
@@ -217,12 +229,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Премахването на файловото разширение \"{old}\" може да направи файла нечетлив.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Добавянето на файловото разширение \"{new}\" може да направи файла нечетлив.",
     "Do not show this dialog again." : "Не показвай този диалогов прозорец отново.",
+    "Cancel" : "Отказ",
+    "Rename" : "Преименувай",
     "Select file or folder to link to" : "Избор на файл или папка, към които да поставите връзка",
     "Choose {file}" : "Изберете {file}",
     "Files settings" : "Настройки на файловете",
-    "Share" : "Споделяне",
-    "Shared by link" : "Споделени с връзка",
-    "Shared" : "Споделен",
     "Switch to list view" : "Превключване към изглед на списък",
     "Switch to grid view" : "Превключване към мрежов изглед",
     "The file could not be found" : "Файлът не може да бъде намерен",
@@ -238,14 +249,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Качете съдържание или синхронизирайте с вашите устройства!",
     "Go back" : "Назад",
     "Views" : "Изгледи",
-    "You" : "Вие",
-    "Shared multiple times with different people" : "Споделяно многократно с различни хора",
-    "Unable to change the favorite state of the file" : "Не може да се промени любимото състояние на файла",
-    "Error while loading the file data" : "Грешка при зареждането на файловете.",
-    "Owner" : "Създател",
-    "Remove from favorites" : "Премахни от любимите",
-    "Add to favorites" : "Добави към любимите",
-    "Tags" : "Етикети",
     "Your files" : "Вашите файлове",
     "Open in files" : "Отваряне във файлове",
     "File cannot be accessed" : "Файлът не е достъпен",
@@ -291,28 +294,28 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["На път сте да изтриете елемента {count} за постоянно","На път сте да изтриете елементите {count} за постоянно"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["На път сте да изтриете {count} елемент","На път сте да изтриете {count} елементи"],
     "Confirm deletion" : "Потвърдете изтриването",
-    "Cancel" : "Отказ",
     "Download" : "Изтегли",
     "The requested file is not available." : "Заявеният файл не е наличен.",
     "The requested files are not available." : "Заявените файлове не са налични.",
+    "Add to favorites" : "Добави към любимите",
+    "Remove from favorites" : "Премахни от любимите",
     "Add or remove favorite" : "Добавете или премахнете любими",
-    "Moving \"{source}\" to \"{destination}\" …" : "Преместване на \"{source}“ към “{destination}\"…",
-    "Copying \"{source}\" to \"{destination}\" …" : "Копиране на \"{source}“ в “{destination}\"…",
+    "Move" : "Преместване",
+    "Copy" : "Копирай",
+    "Move or copy" : "Премести или копирай",
     "Destination is not a folder" : "Предназначчението не е папка",
     "This file/folder is already in that directory" : "Този файл/папка вече е в тази директория",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Не можете да преместите файл/папка в папка или в подпапка",
-    "(copy)" : "(копие)",
-    "(copy %n)" : "(копирай %n)",
     "A file or folder with that name already exists in this folder" : "В тази папка вече съществува файл или папка с това име",
     "The files are locked" : "Файловете са заключени",
     "The file does not exist anymore" : "Файлът вече не съществува",
+    "Moving \"{source}\" to \"{destination}\" …" : "Преместване на \"{source}“ към “{destination}\"…",
+    "Copying \"{source}\" to \"{destination}\" …" : "Копиране на \"{source}“ в “{destination}\"…",
     "Choose destination" : "Изберете дестинация",
     "Copy to {target}" : "Копиране в {target}",
-    "Copy" : "Копирай",
     "Move to {target}" : "Преместване на {target}",
-    "Move" : "Преместване",
     "Move or copy operation failed" : "Операцията за преместване или копиране не бе успешна",
-    "Move or copy" : "Премести или копирай",
+    "Open folder" : "Отвори папката",
     "Open folder {displayName}" : "Отворете папка {displayName}",
     "Open in Files" : "Отворете във Файлове",
     "Open locally" : "Локално отваряне",
@@ -321,22 +324,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Файлът вече би трябвало да се отвори на вашето устройство. Ако не се отвори, моля, проверете дали имате инсталирано настолното приложение.",
     "Retry and close" : "Опитайте отново и затворете",
     "Open online" : "Отворете онлайн",
-    "Rename" : "Преименувай",
     "Details" : "Подробности",
     "View in folder" : "Преглед в папката",
-    "Today" : "Днес",
-    "Last 7 days" : "Последни 7 дни",
-    "Last 30 days" : "Последните 30 дни",
-    "This year ({year})" : "Тази година ({year})",
-    "Last year ({year})" : "Миналата година ({year})",
-    "Documents" : "Документи",
-    "Spreadsheets" : "Електронни таблици",
-    "Presentations" : "Презентации",
-    "PDFs" : "PDF-и",
-    "Folders" : "Папки",
-    "Audio" : "Аудио",
-    "Images" : "Изображения",
-    "Videos" : "Видеа",
+    "Type" : "Тип",
     "Created new folder \"{name}\"" : "Създадена е нова папка “{name}\"",
     "Unable to initialize the templates directory" : "Неуспешно инициализиране на директорията с шаблони",
     "Create templates folder" : "Създаване на папка за шаблони",
@@ -352,10 +342,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Някои файлове не можаха да бъдат качени",
     "Files uploaded successfully" : "Файловете са качени успешно",
     "No files to process" : "Няма файлове за обработка",
-    "Some files could not be copied" : "Някои файлове не можаха да бъдат копирани",
-    "Some files could not be moved" : "Някои файлове не могат да бъдат преместени",
     "Files copied successfully" : "Файловете са успешно копирани",
     "Files moved successfully" : "Файловете са преместени успешно",
+    "Some files could not be copied" : "Някои файлове не можаха да бъдат копирани",
+    "Some files could not be moved" : "Някои файлове не могат да бъдат преместени",
     "Conflicts resolution skipped" : "Разрешаването на конфликти е пропуснато",
     "Upload cancelled" : "Качването е отменено",
     "Could not rename \"{oldName}\", it does not exist any more" : "Файлът \"{oldName}\" не може да бъде преименуван защото не съществува",
@@ -396,10 +386,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Качи (макс. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "След активиране на съвместимите с Windows имена на файлове, съществуващите файлове вече не могат да бъдат променяни, но могат да бъдат преименувани на валидни нови имена от техния собственик.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Възможно е също така автоматично мигриране на файлове след активиране на тази настройка. Моля, вижте документацията за командата occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Преименуван \"{oldName}\" на \"{newName}\"",
+    "Clear filter" : "Изчстиване на филтър",
     "\"{displayName}\" failed on some elements" : "\"{displayName}“ неуспешно при някои елементи",
     "\"{displayName}\" batch action executed successfully" : " Пакетното действие „{displayName}“ е изпълнено успешно",
     "\"{displayName}\" action failed" : "Действието „{displayName}“ е неуспешно",
     "Submitting fields …" : "Изпращане на полета...",
+    "Shared by link" : "Споделени с връзка",
+    "Shared" : "Споделен",
     "\"{displayName}\" action executed successfully" : "Действието „{displayName}“ е изпълнено успешно",
     "Filter file names …" : "Филтриране на имена на файлове...",
     "Clipboard is not available" : "Клипбордът не е достъпен",
@@ -429,6 +423,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Придвижете се до файла отдясно (в режим на мрежа)",
     "Toggle the grid view" : "Превключване на мрежовия изглед",
     "Open the sidebar for a file" : "Отваряне на страничната лента за файл",
+    "You" : "Вие",
+    "Shared multiple times with different people" : "Споделяно многократно с различни хора",
+    "Unable to change the favorite state of the file" : "Не може да се промени любимото състояние на файла",
+    "Error while loading the file data" : "Грешка при зареждането на файловете.",
+    "Tags" : "Етикети",
     "Save as …" : "Запази като...",
     "Converting files …" : "Конвертиране на файлове...",
     "Converting file …" : "Файлът се преобразува...",
@@ -436,6 +435,8 @@ OC.L10N.register(
     "Edit locally" : "Локално редактиране",
     "Moving \"{source}\" to \"{destination}\" …" : "Преместване на \"{source}\" към \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Копиране на \"{source}\" в \"{destination}\" …",
+    "(copy)" : "(копие)",
+    "(copy %n)" : "(копирай %n)",
     "Move cancelled" : "Преместването е отменено",
     "Cancelled move or copy of \"{filename}\"." : "Преместването или копирането на \"{filename}\" е отменено.",
     "Cancelled move or copy operation" : "Операцията за преместване или копиране е отменена",
@@ -444,6 +445,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Създаването на нова папка е отменено",
     "This directory is unavailable, please check the logs or contact the administrator" : "Директорията не е налична. Проверете журнала или се свържете с администратора",
     "All folders" : "Всички папки",
+    "Open file sidebar" : "Отворете страничната лента на файла",
     "Search everywhere …" : "Търсете навсякъде...",
     "Search here …" : "Търсете тук...",
     "Preparing …" : "Подготвя се..."
