@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Aktuelles Verzeichnis neu laden",
     "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}\" wechseln",
     "Current directory path" : "Aktueller Verzeichnispfad",
+    "Share" : "Teilen",
+    "Reload content" : "Inhalt erneut laden",
     "Your have used your space quota and cannot upload files anymore" : "Dein Speicherplatzkontigent ist aufgebraucht, du kannst keine weiteren Dateien hochladen.",
     "You do not have permission to upload or create files here." : "Du hast nicht die Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
     "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Dieser Knoten ist nicht verfügbar.",
     "Another entry with the same name already exists." : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
     "Invalid filename." : "Ungültiger Dateiname.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
     "Rename file" : "Datei umbenennen",
     "Folder" : "Ordner",
     "Unknown file type" : "Unbekannter Dateityp",
@@ -102,21 +103,71 @@ OC.L10N.register(
     "{ext} text" : "{ext}-Text",
     "Pending" : "Ausstehend",
     "Unknown date" : "Unbekanntes Datum",
-    "Clear filter" : "Filter zurücksetzen",
-    "Modified" : "Geändert",
-    "Search everywhere" : "Überall suchen",
-    "Type" : "Typ",
     "Active filters" : "Aktive Filter",
     "Remove filter" : "Filter entfernen",
+    "Today" : "Heute",
+    "Last 7 days" : "Die letzten 7 Tage",
+    "Last 30 days" : "Die letzten 30 Tage",
+    "This year ({year})" : "Dieses Jahr ({year})",
+    "Last year ({year})" : "Letztes Jahr ({year})",
+    "Custom range" : "Benutzerdefinierter Bereich",
+    "Custom date range" : "Benutzerdefinierter Zeitbereich",
+    "Search everywhere" : "Überall suchen",
+    "Documents" : "Dokumente",
+    "Spreadsheets" : "Tabellenkalkulationen",
+    "Presentations" : "Präsentationen",
+    "PDFs" : "PDFs",
+    "Folders" : "Ordner",
+    "Audio" : "Audio",
+    "Images" : "Bilder",
+    "Videos" : "Videos",
+    "Filters" : "Filter",
+    "Back to filters" : "Zurück zu den Filtern",
+    "Appearance" : "Aussehen",
+    "Show hidden files" : "Versteckte Dateien anzeigen",
+    "Show file type column" : "Dateityp-Spalte anzeigen",
+    "Show file extensions" : "Dateierweiterungen anzeigen",
+    "Crop image previews" : "Bildvorschauen zuschneiden",
+    "General" : "Allgemein",
+    "Sort favorites first" : "Favoriten zuerst sortieren",
+    "Sort folders before files" : "Ordner vor Dateien sortieren",
+    "Enable folder tree view" : "Ordnerbaumansicht aktivieren",
+    "Default view" : "Standardansicht",
+    "All files" : "Alle Dateien",
+    "Personal files" : "Persönliche Dateien",
+    "Additional settings" : "Zusätzliche Einstellungen",
+    "Actions" : "Aktionen",
+    "File actions" : "Dateiaktionen",
+    "Selection" : "Auswahl",
+    "Select all files" : "Alle Dateien auswählen",
+    "Deselect all" : "Auswahl aufheben",
+    "Select or deselect" : "Aus- oder abwählen",
+    "Select a range" : "Einen Bereich auswählen",
+    "Navigation" : "Navigation",
+    "Go to parent folder" : "Zum übergeordneten Ordner wechseln",
+    "Go to file above" : "Zur Datei darüber wechseln",
+    "Go to file below" : "Zur Datei darunter wechseln",
+    "Go left in grid" : "Im Raster nach links gehen",
+    "Go right in grid" : "Im Raster nach rechts gehen",
+    "View" : "Ansehen",
+    "Toggle grid view" : "Rasteransicht umschalten",
+    "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
+    "Warnings" : "Warnungen",
+    "Warn before changing a file extension" : "Vor der Änderung einer Dateierweiterung warnen",
+    "Warn before deleting a file" : "Warnung vor dem Löschen einer Datei",
+    "WebDAV URL" : "WebDAV-URL",
+    "Create an app password" : "Ein App-Passwort erstellen",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Erforderlich für die WebDAV-Authentifizierung, da für dieses Konto die Zwei-Faktor-Authentifizierung aktiviert ist.",
+    "How to access files using WebDAV" : "So greifst du mit WebDAV auf Dateien zu",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
     "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
     "Name" : "Name",
     "File type" : "Dateityp",
     "Size" : "Größe",
+    "Modified" : "Geändert",
     "{displayName}: failed on some elements" : "{displayName}: Ist bei einigen Elementen fehlgeschlagen",
     "{displayName}: done" : "{displayName}: Abgeschlossen",
     "{displayName}: failed" : "{displayName}: Fehlgeschlagen",
-    "Actions" : "Aktionen",
     "(selected)" : "(ausgewählt)",
     "List of files and folders." : "Liste der Dateien und Ordner",
     "You have used your space quota and cannot upload files anymore." : "Dein Speicherplatzkontigent ist aufgebraucht, Du kannst keine weiteren Dateien hochladen.",
@@ -128,6 +179,7 @@ OC.L10N.register(
     "Search here …" : "Hier suchen …",
     "Search scope options" : "Suchbereichsoptionen",
     "Search here" : "Hier suchen",
+    "Owner" : "Besitzer",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
     "{used} of {quota} used" : "{used} von {quota} verwendet",
     "{relative}% used" : "{relative} % verwendet",
@@ -147,7 +199,7 @@ OC.L10N.register(
     "Preparing …" : "Bereite vor …",
     "Refresh" : "Aktualisieren",
     "All files have been santized for Windows filename support." : "Alle Dateien wurden für die Windows-Dateinamenunterstützung bereinigt.",
-    "Some files could not be sanitized, please check your logs." : "Einige Dateien konnten nicht bereinigt werden. Bitte überprüfen Sie Ihre Protokolle.",
+    "Some files could not be sanitized, please check your logs." : "Einige Dateien konnten nicht bereinigt werden. Bitte die Protokolle überprüfen.",
     "Sanitization errors" : "Bereinigungsfehler",
     "Not sanitized filenames" : "Nicht bereinigte Dateinamen",
     "Windows filename support has been enabled." : "Windows Dateinamenunterstützung wurde aktiviert.",
@@ -181,56 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Entfernen der Dateierweiterung \"{old}\" kann dazu führen, dass die Datei unlesbar wird.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Hinzufügen der Dateierweiterung \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
     "Do not show this dialog again." : "Diesen Dialog nicht mehr anzeigen.",
+    "Rename file to hidden" : "Datei in versteckt umbenennen",
+    "Prefixing a filename with a dot may render the file hidden." : "Das Voranstellen eines Punkts vor einen Dateinamen kann dazu führen, dass die Datei ausgeblendet wird.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Soll die Datei in \"{filename}\" umbenannt werden?",
+    "Cancel" : "Abbrechen",
+    "Rename" : "Umbenennen",
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
     "Choose {file}" : "{file} auswählen",
-    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
-    "WebDAV URL copied" : "WebDAV-URL kopiert",
     "Files settings" : "Dateien-Einstellungen",
-    "General" : "Allgemein",
-    "Default view" : "Standardansicht",
-    "All files" : "Alle Dateien",
-    "Personal files" : "Persönliche Dateien",
-    "Sort favorites first" : "Favoriten zuerst sortieren",
-    "Sort folders before files" : "Ordner vor Dateien sortieren",
-    "Folder tree" : "Ordnerbaum",
-    "Appearance" : "Aussehen",
-    "Show hidden files" : "Versteckte Dateien anzeigen",
-    "Show file type column" : "Dateityp-Spalte anzeigen",
-    "Show file extensions" : "Dateierweiterungen anzeigen",
-    "Crop image previews" : "Bildvorschauen zuschneiden",
-    "Additional settings" : "Zusätzliche Einstellungen",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV-URL",
-    "Copy" : "Kopieren",
-    "How to access files using WebDAV" : "So greifst du mit WebDAV auf Dateien zu",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Für dein Konto ist die Zwei-Faktor-Authentifizierung aktiviert. Zur Verbindung eines externen WebDAV-Clients ist daher die Verwendung eines App-Passwortes erforderlich.",
-    "Warnings" : "Warnungen",
-    "Warn before changing a file extension" : "Vor der Änderung einer Dateierweiterung warnen",
-    "Warn before deleting files" : "Vor dem Löschen von Dateien warnen",
-    "Keyboard shortcuts" : "Tastaturkürzel",
-    "File actions" : "Dateiaktionen",
-    "Rename" : "Umbenennen",
-    "Delete" : "Löschen",
-    "Add or remove favorite" : "Favorit hinzufügen oder entfernen",
-    "Manage tags" : "Schlagworte verwalten",
-    "Selection" : "Auswahl",
-    "Select all files" : "Alle Dateien auswählen",
-    "Deselect all" : "Auswahl aufheben",
-    "Select or deselect" : "Aus- oder abwählen",
-    "Select a range" : "Einen Bereich auswählen",
-    "Navigation" : "Navigation",
-    "Go to parent folder" : "Zum übergeordneten Ordner wechseln",
-    "Go to file above" : "Zur Datei darüber wechseln",
-    "Go to file below" : "Zur Datei darunter wechseln",
-    "Go left in grid" : "Im Raster nach links gehen",
-    "Go right in grid" : "Im Raster nach rechts gehen",
-    "View" : "Ansehen",
-    "Toggle grid view" : "Rasteransicht umschalten",
-    "Open file sidebar" : "Datei-Seitenleiste öffnen",
-    "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
-    "Share" : "Teilen",
-    "Shared by link" : "Über einen Link geteilt",
-    "Shared" : "Geteilt",
     "Switch to list view" : "Zur Listenansicht wechseln",
     "Switch to grid view" : "Zur Kachelansicht wechseln",
     "The file could not be found" : "Die Datei konnte nicht gefunden werden",
@@ -240,20 +250,14 @@ OC.L10N.register(
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
     "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "unbekannte Fehler während des Hochladens",
+    "File list is reloading" : "Dateiliste wird neu geladen",
     "Loading current folder" : "Lade aktuellen Ordner",
     "Retry" : "Wiederholen",
     "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere sie mit deinen Geräten!",
     "Go back" : "Zurückgehen",
     "Views" : "Ansichten",
-    "You" : "Du",
-    "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
-    "Unable to change the favorite state of the file" : "Der Favoriten-Status der Datei kann nicht geändert werden",
-    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
-    "Owner" : "Besitzer",
-    "Remove from favorites" : "Aus Favoriten entfernen",
-    "Add to favorites" : "Zu den Favoriten hinzufügen",
-    "Tags" : "Schlagworte",
+    "Loading …" : "Lade …",
     "Your files" : "Deine Dateien",
     "Open in files" : "In Dateien öffnen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
@@ -277,14 +281,15 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Fehler beim Konvertieren der Dateien: {message}",
     "All files failed to be converted" : "Alle Dateien konnten nicht konvertiert werden",
     "One file could not be converted: {message}" : "Eine Datei konnte nicht konvertiert werden: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Eine Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Eine Datei konvertiert","%n Dateien konvertiert"],
-    "Files successfully converted" : "Dateien konvertiert",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
+    "_%n file converted_::_%n files converted_" : ["%n Datei konvertiert","%n Dateien konvertiert"],
+    "Files converted" : "Dateien konvertiert",
     "Failed to convert files" : "Dateien konnten nicht konvertiert werden",
     "Converting file …" : "Datei wird konvertiert …",
     "File successfully converted" : "Datei konvertiert",
     "Failed to convert file: {message}" : "Fehler beim Konvertieren der Datei: {message}",
     "Failed to convert file" : "Datei konnte nicht konvertiert werden",
+    "Delete" : "Löschen",
     "Leave this share" : "Diese Freigabe verlassen",
     "Leave these shares" : "Diese Freigaben verlassen",
     "Disconnect storage" : "Speicher trennen",
@@ -298,26 +303,30 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sie sind dabei, {count} Element endgültig zu löschen","Du bist dabei, {count} Elemente endgültig zu löschen."],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Du bist dabei, {count} Elemente zu löschen."],
     "Confirm deletion" : "Löschen bestätigen",
-    "Cancel" : "Abbrechen",
     "Download" : "Herunterladen",
     "The requested file is not available." : "Die angeforderte Datei ist nicht verfügbar.",
     "The requested files are not available." : "Die angeforderten Dateien sind nicht verfügbar.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "Add to favorites" : "Zu den Favoriten hinzufügen",
+    "Remove from favorites" : "Aus Favoriten entfernen",
+    "Add or remove favorite" : "Favorit hinzufügen oder entfernen",
+    "Move" : "Verschieben",
+    "Copy" : "Kopieren",
+    "Move or copy" : "Verschieben oder kopieren",
     "Destination is not a folder" : "Ziel ist kein Ordner",
     "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden.",
-    "(copy)" : "(Kopie)",
-    "(copy %n)" : "(Kopie %n)",
     "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
     "The files are locked" : "Die Dateien sind gesperrt",
     "The file does not exist anymore" : "Die Datei existiert nicht mehr",
+    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
+    "Moving {count} files to \"{destination}\" …" : "Verschiebe {count} Dateien nach \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "Copying {count} files to \"{destination}\" …" : "Kopiere {count} Dateien nach \"{destination}\" …",
     "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
     "Move to {target}" : "Nach {target} verschieben",
-    "Move" : "Verschieben",
     "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
-    "Move or copy" : "Verschieben oder kopieren",
+    "Open folder" : "Ordner öffnen",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
     "Open in Files" : "In Dateien öffnen",
     "Open locally" : "Lokal öffnen",
@@ -327,26 +336,17 @@ OC.L10N.register(
     "Retry and close" : "Erneut versuchen und schließen",
     "Open online" : "Online öffnen",
     "Details" : "Details",
+    "Open the details sidebar" : "Die Details-Seitenleiste öffnen",
+    "Unfavorite" : "Nicht favorisieren",
     "View in folder" : "In Ordner anzeigen",
-    "Today" : "Heute",
-    "Last 7 days" : "Die letzten 7 Tage",
-    "Last 30 days" : "Die letzten 30 Tage",
-    "This year ({year})" : "Dieses Jahr ({year})",
-    "Last year ({year})" : "Letztes Jahr ({year})",
-    "Documents" : "Dokumente",
-    "Spreadsheets" : "Tabellenkalkulationen",
-    "Presentations" : "Präsentationen",
-    "PDFs" : "PDFs",
-    "Folders" : "Ordner",
-    "Audio" : "Audio",
-    "Images" : "Bilder",
-    "Videos" : "Videos",
+    "Type" : "Typ",
     "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
     "Unable to initialize the templates directory" : "Der Vorlagenordner konnte nicht initialisiert werden",
     "Create templates folder" : "Vorlagenordner erstellen",
     "Templates" : "Vorlagen",
     "New template folder" : "Neuer Vorlagenordner",
     "In folder" : "Im Ordner",
+    "Pick folder to search in" : "Ordner auswählen, in dem gesucht werden soll",
     "Search in all files" : "In allen Dateien suchen",
     "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
     "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
@@ -356,14 +356,14 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden",
     "Files uploaded successfully" : "Dateien hochgeladen",
     "No files to process" : "Keine Dateien zum Verarbeiten",
-    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
-    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden.",
     "Files copied successfully" : "Dateien kopiert",
     "Files moved successfully" : "Dateien verschoben",
+    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
+    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden.",
     "Conflicts resolution skipped" : "Konfliktlösung übersprungen",
     "Upload cancelled" : "Hochladen abgebrochen",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert.",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wähle einen anderen Namen.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}\" wird bereits im Ordner \"{dir}\" verwendet. Bitte wähle einen anderen Namen.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden.",
     "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
     "This folder is unavailable, please try again later or contact the administration" : "Dieser Ordner ist nicht verfügbar. Bitte später erneut versuchen oder an die Administration wenden",
@@ -381,6 +381,7 @@ OC.L10N.register(
     "No favorites yet" : "Noch keine Favoriten vorhanden",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
     "List of your files and folders." : "Liste deiner Dateien und Ordner",
+    "Folder tree" : "Ordnerbaum",
     "List of your files and folders that are not shared." : "Liste deiner Dateien und Ordner, die nicht geteilt wurden.",
     "No personal files found" : "Keine persönlichen Dateien gefunden",
     "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
@@ -398,21 +399,28 @@ OC.L10N.register(
     "renamed file" : "Umbenannte Datei",
     "Upload (max. %s)" : "Hochladen (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Nach dem Aktivieren dieser Einstellung ist es auch möglich, Dateien automatisch zu migrieren. Weitere Informationen finden sich in der Dokumentation zum \"occ“-Befehl.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Nach dem Aktivieren dieser Einstellung ist es auch möglich, Dateien automatisch zu migrieren. Weitere Informationen finden sich in der Dokumentation zum \"occ\"-Befehl.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
+    "Clear filter" : "Filter zurücksetzen",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
     "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" ausgeführt",
     "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
     "Submitting fields …" : "Felder werden übermittelt …",
+    "Shared by link" : "Über einen Link geteilt",
+    "Shared" : "Geteilt",
     "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" ausgeführt",
     "Filter file names …" : "Dateinamen filtern …",
+    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
     "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
     "Enable the grid view" : "Kachelansicht aktivieren",
     "Enable folder tree" : "Ordnerstruktur aktivieren",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "In die Zwischenablage kopieren",
     "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen.",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn du 2FA aktiviert hast, musst du ein neues App-Passwort erstellen und verwenden, indem du hier klickst.",
     "Prevent warning dialogs from open or reenable them." : "Öffnen von Warndialogen verhindern oder diese erneut aktivieren.",
     "Show a warning dialog when changing a file extension." : "Beim Ändern einer Dateierweiterung einen Warndialog anzeigen.",
+    "Keyboard shortcuts" : "Tastaturkürzel",
     "Speed up your Files experience with these quick shortcuts." : "Mit diesen Schnellzugriffen schneller mit Dateien arbeiten.",
     "Open the actions menu for a file" : "Aktionsmenü für eine Datei öffnen",
     "Rename a file" : "Eine Datei umbenennen",
@@ -429,6 +437,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (in der Kachelansicht)",
     "Toggle the grid view" : "Kachelansicht umschalten",
     "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen",
+    "You" : "Du",
+    "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
+    "Unable to change the favorite state of the file" : "Der Favoriten-Status der Datei kann nicht geändert werden",
+    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
+    "Tags" : "Schlagworte",
     "Save as …" : "Speichern als …",
     "Converting files …" : "Dateien werden konvertiert …",
     "Converting file …" : "Datei wird konvertiert …",
@@ -436,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Lokal bearbeiten",
     "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "(copy)" : "(Kopie)",
+    "(copy %n)" : "(Kopie %n)",
     "Move cancelled" : "Verschieben abgebrochen",
     "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
     "Cancelled move or copy operation" : "Verschieben oder Kopieren abgebrochen",
@@ -444,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
     "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder die Administration kontaktieren.",
     "All folders" : "Alle Ordner",
+    "Open file sidebar" : "Datei-Seitenleiste öffnen",
     "Search everywhere …" : "Überall suchen  …",
     "Search here …" : "Hier suchen …",
     "Preparing …" : "Bereite vor …"
