@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Превчитај ја повторно моменталната папка",
     "Go to the \"{dir}\" directory" : "Оди до \"{dir}\" папката",
     "Current directory path" : "Патека до оваа папка",
+    "Share" : "Сподели",
+    "Reload content" : "Повторно вчитај ја содржината",
     "Your have used your space quota and cannot upload files anymore" : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки",
     "You do not have permission to upload or create files here." : "Немате дозвола да прикачувате или да креирате датотеки овде",
     "Drag and drop files here to upload" : "Повлечи и испушти датотеки за прикачување",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Нодот е недостапен",
     "Another entry with the same name already exists." : "Друг запис со исто име веќе постои.",
     "Invalid filename." : "Невалидно име.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Преименувано \"{oldName}\" во \"{newName}\"",
     "Rename file" : "Преименувај датотека",
     "Folder" : "Папка",
     "Unknown file type" : "Непознат тип на датотека",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} текст",
     "Pending" : "Чека",
     "Unknown date" : "Непознат датум",
-    "Clear filter" : "Исчисти филтри",
-    "Modified" : "Променето",
-    "Search everywhere" : "Барај насекаде",
-    "Type" : "Вид",
     "Active filters" : "Активни филтри",
     "Remove filter" : "Отстрани филтер",
+    "Today" : "Денес",
+    "Last 7 days" : "Предходни 7 дена",
+    "Last 30 days" : "Предходни 30 дена",
+    "This year ({year})" : "Оваа година ({year})",
+    "Last year ({year})" : "Минатата година ({year})",
+    "Custom range" : "Прилагоден опсег",
+    "Custom date range" : "Прилагоден временски опсег",
+    "Search everywhere" : "Барај насекаде",
+    "Documents" : "Документи",
+    "Spreadsheets" : "Табели",
+    "Presentations" : "Презентации",
+    "PDFs" : "PDF-и",
+    "Folders" : "Папки",
+    "Audio" : "Аудио",
+    "Images" : "Слики",
+    "Videos" : "Видеа",
+    "Filters" : "Филтри",
+    "Back to filters" : "Назад до филтрите",
     "Appearance" : "Изглед",
     "Show hidden files" : "Прикажи сокриени датотеки",
     "Show file type column" : "Прикажи колона за тип на датотека",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "Помести се десно во мрежата",
     "View" : "Поглед",
     "Toggle grid view" : "Промена во мрежа",
-    "Open file sidebar" : "Отвори странична лента на датотеката",
     "Show those shortcuts" : "Покажи ги овие кратенки",
     "Warnings" : "Предупредувања",
     "Warn before changing a file extension" : "Предупреди пред промена на наставката на датотека",
@@ -149,6 +163,7 @@ OC.L10N.register(
     "Name" : "Име",
     "File type" : "Вид на датотека",
     "Size" : "Големина",
+    "Modified" : "Променето",
     "{displayName}: failed on some elements" : "{displayName}: неуспешно на некои елементи",
     "{displayName}: done" : "{displayName}: завршено",
     "{displayName}: failed" : "{displayName}: неуспешно",
@@ -217,12 +232,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Остранување на екстензијата \"{old}\" може да ја направи датотеката нечитлива.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Додавање на екстензијата \"{new}\" може да ја направи датотеката нечитлива.",
     "Do not show this dialog again." : "Не го прикажувај овој дијалог повторно.",
+    "Cancel" : "Откажи",
+    "Rename" : "Преименувај",
     "Select file or folder to link to" : "Изберете датотека или папка за линк до",
     "Choose {file}" : "Избери {file}",
     "Files settings" : "Параметри за датотеки",
-    "Share" : "Сподели",
-    "Shared by link" : "Споделено со линк",
-    "Shared" : "Споделено",
     "Switch to list view" : "Прикажи поглед во листа",
     "Switch to grid view" : "Прикажи поглед во мрежа",
     "The file could not be found" : "Датотеката неможе да биде пројандена",
@@ -232,6 +246,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Грешка при прикачување: {message}",
     "Error during upload, status code {status}" : "Грешка при прикачување, статус код {status}",
     "Unknown error during upload" : "Непозната грешка при прикачување",
+    "File list is reloading" : "Листата на датотеки се вчитува",
     "Loading current folder" : "Вчитување на моменталната папка",
     "Retry" : "Обидете се повторно",
     "No files in here" : "Тука нема датотеки",
@@ -284,30 +299,27 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Сакате да избришете {count} датотека","Сакате да избришете {count} датотеки"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Сакате да избришете {count} датотека","Сакате да избришете {count} датотеки"],
     "Confirm deletion" : "Потврди бришење",
-    "Cancel" : "Откажи",
     "Download" : "Преземи",
     "The requested file is not available." : "Бараната датотека не е достапна.",
     "The requested files are not available." : "Бараните датотеки не се достапни.",
     "Add to favorites" : "Додади во фаворити",
     "Remove from favorites" : "Отстрани од фаворити",
     "Add or remove favorite" : "Додај или отстрани омилено",
-    "Moving \"{source}\" to \"{destination}\" …" : "Преместување \"{source}\" во \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Копирање \"{source}\" во \"{destination}\" …",
+    "Move" : "Премести",
+    "Copy" : "Копирај",
+    "Move or copy" : "Премести или копирај",
     "Destination is not a folder" : "Дестинацијата не е папка",
     "This file/folder is already in that directory" : "Оваа папка/датотека се наоѓа веќе во таа папка",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможете да преместите датотека/папка во себеси или во подпапка во себеси",
-    "(copy)" : "(копирај)",
-    "(copy %n)" : "(копирај %n)",
     "A file or folder with that name already exists in this folder" : "Датотека или папка со тоа име веќе постои во оваа папка",
     "The files are locked" : "Датотекатите се заклучени",
     "The file does not exist anymore" : "Датотеката не постои",
+    "Moving \"{source}\" to \"{destination}\" …" : "Преместување \"{source}\" во \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Копирање \"{source}\" во \"{destination}\" …",
     "Choose destination" : "Избери дестинација",
     "Copy to {target}" : "Копирај во {target}",
-    "Copy" : "Копирај",
     "Move to {target}" : "Премести во {target}",
-    "Move" : "Премести",
     "Move or copy operation failed" : "Преместувањето или копирањето не успеа",
-    "Move or copy" : "Премести или копирај",
     "Open folder" : "Отвори папка",
     "Open folder {displayName}" : "Отвори папка {displayName}",
     "Open in Files" : "Отвори во датотеките",
@@ -317,28 +329,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Датотеката сега треба да се отвори на твојот уред. Ако не се отвори, провери дали ја имаш инсталирано десктоп апликацијата.",
     "Retry and close" : "Повтори и затвори",
     "Open online" : "Отвори онлајн",
-    "Rename" : "Преименувај",
     "Details" : "Детали:",
+    "Open the details sidebar" : "Отвори странична лента со детали",
+    "Unfavorite" : "Од-означи",
     "View in folder" : "Погледни во папката",
-    "Today" : "Денес",
-    "Last 7 days" : "Предходни 7 дена",
-    "Last 30 days" : "Предходни 30 дена",
-    "This year ({year})" : "Оваа година ({year})",
-    "Last year ({year})" : "Минатата година ({year})",
-    "Documents" : "Документи",
-    "Spreadsheets" : "Табели",
-    "Presentations" : "Презентации",
-    "PDFs" : "PDF-и",
-    "Folders" : "Папки",
-    "Audio" : "Аудио",
-    "Images" : "Слики",
-    "Videos" : "Видеа",
+    "Type" : "Вид",
     "Created new folder \"{name}\"" : "Креирана нова папка \"{name}\"",
     "Unable to initialize the templates directory" : "Не може да се иницијализира папка за шаблони",
     "Create templates folder" : "Креирај папка за шаблони",
     "Templates" : "Шаблони",
     "New template folder" : "Нова папка за шаблони",
     "In folder" : "Во папка",
+    "Pick folder to search in" : "Избери папка за да пребараш во неа",
     "Search in all files" : "Пребарај во сите датотеки",
     "Search in folder: {folder}" : "Барај во папка: {folder}",
     "One of the dropped files could not be processed" : "Една од испуштените датотеки неможе да се процесоира",
@@ -348,10 +350,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Некој датотеки неможат да се прикачат",
     "Files uploaded successfully" : "Успешно прикачени датотеки",
     "No files to process" : "Нема датотеки за обработка",
-    "Some files could not be copied" : "Некои датотеки не можеа да се копираат",
-    "Some files could not be moved" : "Некои датотеки не можат да се преместат",
     "Files copied successfully" : "Датотеките се успешно копирани",
     "Files moved successfully" : "Датотеките се успешно преместени",
+    "Some files could not be copied" : "Некои датотеки не можеа да се копираат",
+    "Some files could not be moved" : "Некои датотеки не можат да се преместат",
     "Conflicts resolution skipped" : "Разрешувањето на конфликти е прескокнато",
     "Upload cancelled" : "Прикачувањето е откажано",
     "Could not rename \"{oldName}\", it does not exist any more" : "Неможе да се преименува \"{oldName}\", не постои повеќе",
@@ -392,10 +394,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Префрлање (макс. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "По овозможување на имиња компатибилни со Windows, постоечките датотеки повеќе не може да се изменуваат, но сопственикот може да ги преименува во валидни нови имиња.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Можно е и автоматски да се мигрираат датотеките по овозможување на оваа поставка — погледни ја документацијата за occ командата.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Преименувано \"{oldName}\" во \"{newName}\"",
+    "Clear filter" : "Исчисти филтри",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" не успеа на некои елементи",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акција е успешно извршена",
     "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
     "Submitting fields …" : "Испраќање полиња ...",
+    "Shared by link" : "Споделено со линк",
+    "Shared" : "Споделено",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
     "Filter file names …" : "Филтрирај имиња на датотеки ...",
     "Clipboard is not available" : "Клипбордот не е достапен",
@@ -437,6 +443,8 @@ OC.L10N.register(
     "Edit locally" : "Уреди локално",
     "Moving \"{source}\" to \"{destination}\" …" : "Се преместува \"{source}\" во \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Се копира \"{source}\" во \"{destination}\" …",
+    "(copy)" : "(копирај)",
+    "(copy %n)" : "(копирај %n)",
     "Move cancelled" : "Преместувањето е откажано",
     "Cancelled move or copy of \"{filename}\"." : "Откажано е преместувањето или копирањето на \"{filename}\".",
     "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
@@ -445,6 +453,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Креирањето на нова папка е откажано",
     "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
     "All folders" : "Сите папки",
+    "Open file sidebar" : "Отвори странична лента на датотеката",
     "Search everywhere …" : "Пребарај насекаде …",
     "Search here …" : "Пребарај тука …",
     "Preparing …" : "Подготовка ..."
