@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Перезавантажити поточний каталог",
     "Go to the \"{dir}\" directory" : "Перейти до каталогу \"{dir}\"",
     "Current directory path" : "Шлях до поточного каталогу",
+    "Share" : "Поширити",
+    "Reload content" : "Перезавантажити вміст",
     "Your have used your space quota and cannot upload files anymore" : "Ви вже використали квоту на місце та не можете завантажувати файли",
     "You do not have permission to upload or create files here." : "У вас відсутній дозвіл завантажувати або створювати тут файли.",
     "Drag and drop files here to upload" : "Перетягніть файли сюди для завантаження",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Цей вузол не доступний",
     "Another entry with the same name already exists." : "Інший запис з таким же ім'ям вже присутній",
     "Invalid filename." : "Недійсне ім'я файлу.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Перейменовано \"{oldName}\" на \"{newName}\"",
     "Rename file" : "Перейменувати файл",
     "Folder" : "Каталог",
     "Unknown file type" : "Невідомий тип файлу",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} текст",
     "Pending" : "Очікування",
     "Unknown date" : "Невідома дата",
-    "Clear filter" : "Очистити фільтр",
-    "Modified" : "Змінено",
-    "Search everywhere" : "Шукати всюди",
-    "Type" : "Тип",
     "Active filters" : "Активні фільтри",
     "Remove filter" : "Вилучити фільтр",
+    "Today" : "Сьогодні",
+    "Last 7 days" : "За останні 7 днів",
+    "Last 30 days" : "За останні 30 днів",
+    "This year ({year})" : "Цього року ({year})",
+    "Last year ({year})" : "Минулого року ({year})",
+    "Custom range" : "Власний діяпазон",
+    "Custom date range" : "Власний вибір проміжку",
+    "Search everywhere" : "Шукати всюди",
+    "Documents" : "Документи",
+    "Spreadsheets" : "Електронні таблиці",
+    "Presentations" : "Презентації",
+    "PDFs" : "Файли PDF",
+    "Folders" : "Каталоги",
+    "Audio" : "Аудіо",
+    "Images" : "Зображення",
+    "Videos" : "Відео",
+    "Filters" : "Фільтри",
+    "Back to filters" : "Повернутися до фільтрів",
     "Appearance" : "Вигляд",
     "Show hidden files" : "Показувати приховані файли",
     "Show file type column" : "Показувати стовпець з типом файлу",
@@ -136,20 +151,20 @@ OC.L10N.register(
     "Go right in grid" : "Перейти праворуч у сітці",
     "View" : "Подання",
     "Toggle grid view" : "Перемкнути подання сіткою",
-    "Open file sidebar" : "Відкрити бічну панель файлів",
     "Show those shortcuts" : "Показувати ці скорочення",
     "Warnings" : "Застереження",
     "Warn before changing a file extension" : "Попереджати перед зміною розширення файлу",
     "Warn before deleting a file" : "Попереджати перед вилученням файлу",
     "WebDAV URL" : "URL-адреса WebDAV",
     "Create an app password" : "Створити пароль застосунку",
-    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Вимагається для авторизації WebDAV, оскільки увімкнено двофакторну авторизацію для цього облікового запису.",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Вимагається для автентифікації WebDAV, оскільки увімкнено двофакторну автентифікацію для цього облікового запису.",
     "How to access files using WebDAV" : "Як отримати доступ до файлів за допомогою WebDAV",
     "Total rows summary" : "Загалом рядків",
     "Toggle selection for all files and folders" : "Перемкнути вибір для всіх файлів та каталогів",
     "Name" : "Ім'я",
     "File type" : "Тип файлу",
     "Size" : "Розмір",
+    "Modified" : "Змінено",
     "{displayName}: failed on some elements" : "{displayName}: не вдалося виконати деякі елементи",
     "{displayName}: done" : "{displayName}: готово",
     "{displayName}: failed" : "{displayName}: не вдалося",
@@ -206,7 +221,7 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Запит на передавання прав власника надіслано",
     "Cannot transfer ownership of a file or folder you do not own" : "Неможливо передати права власності на файл або каталог, якими ви не володієте",
     "Transfer ownership of a file or folder" : "Передавання прав власника на файл або каталог",
-    "Choose file or folder to transfer" : "Виберіть цільовий файл або каталог",
+    "Choose file or folder to transfer" : "Виберіть файл або каталог призначення",
     "Change" : "Змінити",
     "New owner" : "Новий власник",
     "Keep {old}" : "Зберегти {old}",
@@ -218,12 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Вилучення розширення файлу \"{old}\" може зробити файл недоступним.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Додавання розширення до файлу \"{new}\" може зробити файл недоступним.",
     "Do not show this dialog again." : "Не показувати цей діялог подалі.",
+    "Rename file to hidden" : "Перейменувати файл у прихований",
+    "Prefixing a filename with a dot may render the file hidden." : "Якщо додати крапку перед ім'ям файлу зробить файл прихованим.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Дійсно перейменувати файл у \"{filename}\"?",
+    "Cancel" : "Скасувати",
+    "Rename" : "Перейменувати",
     "Select file or folder to link to" : "Виберіть файл або каталог, до якого потрібно застосувати посилання",
     "Choose {file}" : "Виберіть {file}",
     "Files settings" : "Налаштування",
-    "Share" : "Поширити",
-    "Shared by link" : "Доступ за посиланням",
-    "Shared" : "Спільне",
     "Switch to list view" : "У вигляді списку",
     "Switch to grid view" : "У вигляді сітки",
     "The file could not be found" : "Неможливо знайти файл",
@@ -233,6 +250,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Помилка під час завантаження: {message}",
     "Error during upload, status code {status}" : "Помилка під час завантаження, код стану {status}",
     "Unknown error during upload" : "Невідома помилка під час завантаження",
+    "File list is reloading" : "Список файлів перезавантажується",
     "Loading current folder" : "Отримання поточного каталогу",
     "Retry" : "Ще раз",
     "No files in here" : "Тут немає файлів",
@@ -285,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Ви намагаєтеся назавжли вилучити {count} ресурс","Ви намагаєтеся назавжли вилучити {count} ресурси","Ви намагаєтеся назавжли вилучити {count} ресурсів","Ви намагаєтеся назавжли вилучити {count} ресурсів"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Ви намагаєтеся вилучити {count} ресурс","Ви намагаєтеся вилучити {count} ресурси","Ви намагаєтеся  вилучити {count} ресурсів","Ви намагаєтеся вилучити {count} ресурсів"],
     "Confirm deletion" : "Підтвердіть вилучення",
-    "Cancel" : "Скасувати",
     "Download" : "Звантажити",
     "The requested file is not available." : "Запитаний файл відсутній.",
     "The requested files are not available." : "Запитані файли відсутні.",
     "Add to favorites" : "Додати зірочку",
     "Remove from favorites" : "Прибрати зірочку",
     "Add or remove favorite" : "Додати або видалити з улюблених",
-    "Moving \"{source}\" to \"{destination}\" …" : "Переміщення \"{source}\" на \"{destination}\" ...",
-    "Copying \"{source}\" to \"{destination}\" …" : "Копіювання \"{source}\" в \"{destination}\" ...",
+    "Move" : "Перемістити",
+    "Copy" : "Копіювати",
+    "Move or copy" : "Перемістити або копіювати",
     "Destination is not a folder" : "Місце призначення не є каталогом",
     "This file/folder is already in that directory" : "Такий файл чи каталог вже присутні в цьому каталозі",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможливо перемістити файл чи каталог до самого себе або у цей саме підкаталог",
-    "(copy)" : "(копія)",
-    "(copy %n)" : "(копія %n)",
     "A file or folder with that name already exists in this folder" : "Файл чи каталог з таким ім'ям вже присутній в цьому каталозі",
     "The files are locked" : "Файли заблоковано",
     "The file does not exist anymore" : "Цей файл більше недоступний",
+    "Moving \"{source}\" to \"{destination}\" …" : "Переміщення \"{source}\" на \"{destination}\" ...",
+    "Moving {count} files to \"{destination}\" …" : "Переміщення {count} файлів до \"{destination}\" ...",
+    "Copying \"{source}\" to \"{destination}\" …" : "Копіювання \"{source}\" в \"{destination}\" ...",
+    "Copying {count} files to \"{destination}\" …" : "Копіювання {count} файлів до \"{destination}\" ...",
     "Choose destination" : "Виберіть каталог призначення",
     "Copy to {target}" : "Копіювати до {target}",
-    "Copy" : "Копіювати",
     "Move to {target}" : "Перемістити до {target}",
-    "Move" : "Перемістити",
     "Move or copy operation failed" : "Не вдалося скопіювати або перемістити",
-    "Move or copy" : "Перемістити або копіювати",
     "Open folder" : "Відкрити каталог",
     "Open folder {displayName}" : "Відкрити каталог {displayName}",
     "Open in Files" : "Відкрити у Файлах",
@@ -318,29 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Тепер файл можна відкрити на вашому пристрої. Якщо він не відкривається, перевірте, що у вас встановлено настільний клієнт синхронізації.",
     "Retry and close" : "Спробувати ще раз",
     "Open online" : "Відкрити віддалено",
-    "Rename" : "Перейменувати",
     "Details" : "Докладно",
+    "Open the details sidebar" : "Відкрити бічну панель з деталями",
     "Unfavorite" : "Прибрати зірочку",
     "View in folder" : "Переглянути у каталозі",
-    "Today" : "Сьогодні",
-    "Last 7 days" : "За останні 7 днів",
-    "Last 30 days" : "За останні 30 днів",
-    "This year ({year})" : "Цього року ({year})",
-    "Last year ({year})" : "Минулого року ({year})",
-    "Documents" : "Документи",
-    "Spreadsheets" : "Електронні таблиці",
-    "Presentations" : "Презентації",
-    "PDFs" : "Файли PDF",
-    "Folders" : "Каталоги",
-    "Audio" : "Аудіо",
-    "Images" : "Зображення",
-    "Videos" : "Відео",
+    "Type" : "Тип",
     "Created new folder \"{name}\"" : "Створив(-ла) новий каталог \"{name}\"",
     "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
     "Create templates folder" : "Створити каталог для шаблонів",
     "Templates" : "Шаблони",
     "New template folder" : "Новий каталог шаблонів",
     "In folder" : "У каталозі",
+    "Pick folder to search in" : "Вибрати каталог для пошуку",
     "Search in all files" : "Пошук у всіх файлах",
     "Search in folder: {folder}" : "Шукати у каталозі: {folder}",
     "One of the dropped files could not be processed" : "Один із завантажених файлів не вдалося обробити",
@@ -350,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Не вдалося завантажити окремі файли",
     "Files uploaded successfully" : "Файли успішно завантажено",
     "No files to process" : "Відсутні файли для обробки",
-    "Some files could not be copied" : "Неможливо скопіювати окремі файли",
-    "Some files could not be moved" : "Окремі файли неможливо перемістити",
     "Files copied successfully" : "Файли успішно скопійовано",
     "Files moved successfully" : "Файли успішно переміщено",
+    "Some files could not be copied" : "Неможливо скопіювати окремі файли",
+    "Some files could not be moved" : "Окремі файли неможливо перемістити",
     "Conflicts resolution skipped" : "Пропущено розв'язання конфліктів",
     "Upload cancelled" : "Завантаження скасовано",
     "Could not rename \"{oldName}\", it does not exist any more" : "Не вдалося перейментувати \"{oldName}\", оскільки він вже відсутній",
@@ -394,20 +400,24 @@ OC.L10N.register(
     "Upload (max. %s)" : "Завантаження (макс. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Після увімкнення сумісности імен файлів з системою Windows наявні файли неможливо буде змінити, але власники зможуть перейменувати ці файли на нові з дійсними іменами.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Також можлива автоматична міграція файлів після увімкнення цих налаштувань. Ознайомтеся з документацією відповідної команди occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Перейменовано \"{oldName}\" на \"{newName}\"",
+    "Clear filter" : "Очистити фільтр",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" не спрацював у деяких елементах",
     "\"{displayName}\" batch action executed successfully" : "Операцію \"{displayName}\" успішно виконано",
     "\"{displayName}\" action failed" : "Не вдалося виконати \"{displayName}\"",
     "Submitting fields …" : "Надсилання полів ...",
+    "Shared by link" : "Доступ за посиланням",
+    "Shared" : "Спільне",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" успішно виконано",
     "Filter file names …" : "Фільтр за іменем файлу ...",
     "Clipboard is not available" : "Буфер обміну недоступний",
-    "WebDAV URL copied to clipboard" : "Послиання WebDAV скопійовано до буферу обміну",
+    "WebDAV URL copied to clipboard" : "Послиання WebDAV скопійовано до буфера обміну",
     "Enable the grid view" : "Увімкнути подання сіткою",
     "Enable folder tree" : "Увімкнути дерево каталогів",
     "WebDAV" : "WebDAV",
-    "Copy to clipboard" : "Копіювати до буферу обміну",
+    "Copy to clipboard" : "Копіювати до буфера обміну",
     "Use this address to access your Files via WebDAV" : "Адреса для доступу до файлів за допомогою протоколу WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Якщо увімкнено двофакторної авторизацію, вам потрібно створити та використовувати окремий пароль на застосунок. Для цього клацніть тут.",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Якщо увімкнено двофакторної автентифікацію, вам потрібно створити та використовувати окремий пароль на застосунок. Для цього клацніть тут.",
     "Prevent warning dialogs from open or reenable them." : "Не дозволяти показувати діялоги застережень або повторно увімкнути їх.",
     "Show a warning dialog when changing a file extension." : "Показувати діялог застереження у разі зміни розширення файлу.",
     "Keyboard shortcuts" : "Скорочення",
@@ -439,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Відкрити на пристрої",
     "Moving \"{source}\" to \"{destination}\" …" : "Переміщення \"{source}\" до \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Копіювання \"{source}\" до \"{destination}\" …",
+    "(copy)" : "(копія)",
+    "(copy %n)" : "(копія %n)",
     "Move cancelled" : "Переміщення скасовано",
     "Cancelled move or copy of \"{filename}\"." : "Скасовано переміщення або копіювання \"{filename}\".",
     "Cancelled move or copy operation" : "Переміщення або копіювання скасовано",
@@ -447,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Створення нового каталогу скасовано",
     "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступний, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
     "All folders" : "Усі каталоги",
+    "Open file sidebar" : "Відкрити бічну панель файлів",
     "Search everywhere …" : "Шукати всюди ...",
     "Search here …" : "Шукати тут …",
     "Preparing …" : "Підготовка ..."
