@@ -15,13 +15,16 @@ OC.L10N.register(
     "Not supported!" : "Nicht unterstützt!",
     "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
     "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
+    "Unknown" : "Unbekannt",
+    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d Tage, %2$d Stunden, %3$d Minuten, %4$d Sekunden",
+    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d Stunden, %2$d Minuten, %3$d Sekunden",
     "System" : "System",
     "Monitoring" : "Information",
     "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
     "Operating System:" : "Betriebssystem:",
     "CPU:" : "Prozessor:",
-    "Unknown Processor" : "Unbekannter Prozessor",
+    "threads" : "Threads",
     "Memory:" : "Speicher:",
     "Server time:" : "Serverzeit:",
     "Uptime:" : "Betriebszeit:",
@@ -63,11 +66,14 @@ OC.L10N.register(
     "PHP" : "PHP",
     "Version:" : "Version:",
     "Memory limit:" : "Speicherlimit:",
+    "MB" : "MB",
     "Max execution time:" : "Maximale Ausführungszeit:",
+    "seconds" : "Sekunden",
     "Upload max size:" : "Maximale Größe zum Hochladen:",
     "OPcache Revalidate Frequency:" : "OPcache-Revalidierungshäufigkeit:",
     "Extensions:" : "Erweiterungen:",
     "Unable to list extensions" : "Erweiterungen können nicht aufgelistet werden",
+    "PHP Info:" : "PHP Info:",
     "Show phpinfo" : "phpinfo anzeigen",
     "FPM worker pool" : "FPM-Worker-Pool",
     "Pool name:" : "Pool-Name:",
@@ -91,6 +97,7 @@ OC.L10N.register(
     "Skip apps section (including apps section will send an external request to the app store)" : "Abschnitt \"Apps\" überspringen (das Einschließen des Abschnitts \"Apps\" sendet eine externe Anfrage an den App Store)",
     "Skip server update" : "Serveraktualisierung überspringen",
     "To use an access token, please generate one then set it using the following command:" : "Um ein Zugriffstoken zu verwenden, generieren Sie bitte eines und legen Sie es mit dem folgenden Befehl fest:",
-    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergeben Sie dann das Token mit dem Header \"NC-Token\" durch Aufrufen der obigen URL."
+    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergeben Sie dann das Token mit dem Header \"NC-Token\" durch Aufrufen der obigen URL.",
+    "Unknown Processor" : "Unbekannter Prozessor"
 },
 "nplurals=2; plural=(n != 1);");
