@@ -1,12 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
-    "Very weak password" : "Nagyon gyenge jelszó",
-    "Weak password" : "Gyenge jelszó",
-    "So-so password" : "Nem túl jó jelszó",
-    "Good password" : "Jó jelszó",
-    "Strong password" : "Erős jelszó",
     "{actor} added you to group {group}" : "{actor} hozzáadta a(z) {group} csoporthoz",
     "You added {user} to group {group}" : "Hozzáadta {user} felhasználót a(z) {group} csoporthoz",
     "{actor} added {user} to group {group}" : "{actor} hozzáadta {user} felhasználót a(z) {group} csoporthoz",
@@ -44,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "Nem lehet megváltoztatni a személyes jelszót",
     "Saved" : "Mentve",
     "No Login supplied" : "Nincs megadva bejelentkezési adat",
+    "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
     "Unable to change password. Password too long." : "Nem lehet megváltoztatni a jelszót. A jelszó túl hosszú.",
     "Authentication error" : "Hitelesítései hiba",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Kérlek adj meg egy adminisztrátori visszaállító jelszót, vagy az összes felhasználói adat elveszik.",
@@ -100,6 +95,7 @@ OC.L10N.register(
     "Administration privileges" : "Rendszergazdai jogosultságok",
     "Groupware" : "Csoportmunka",
     "Overview" : "Áttekintés",
+    "Quick presets" : "Gyors előbeállítások",
     "Basic settings" : "Alapvető beállítások",
     "Sharing" : "Megosztás",
     "Availability" : "Elérhetőség",
@@ -271,6 +267,7 @@ OC.L10N.register(
     "Featured" : "Kiemelt",
     "This app is supported via your current Nextcloud subscription." : "Az alkalmazás támogatását a jelenlegi Nextcloud előfizetése biztosítja.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "A kiemelt alkalmazásokat a közösség tagjai készítik. Ezek biztosítják a fő funkciókat, és készek az éles használatra.",
+    "Learn more" : "Tudjon meg többet",
     "Disable all" : "Összes tiltása",
     "Download and enable all" : "Összes letöltése és engedélyezése",
     "All apps are up-to-date." : "Minden alkalmazás naprakész.",
@@ -300,7 +297,6 @@ OC.L10N.register(
     "Daemon" : "Démon",
     "Type" : "Típus",
     "Display Name" : "Megjelenítendő név",
-    "Learn more" : "Tudjon meg többet",
     "Confirm" : "Megerősítés",
     "Cancel" : "Mégse",
     "Description" : "Leírás",
@@ -540,6 +536,20 @@ OC.L10N.register(
     "No devices configured." : "Nincs eszköz beállítva.",
     "The following devices are configured for your account:" : "A következő eszközök vannak a fiókjához kapcsolva:",
     "Your browser does not support WebAuthn." : "A böngészője nem támogatja a WebAuthn szabványt.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Fontos, hogy a levelezés be legyen állítva a kiszolgálón, például a jelszó-visszaállítások és az értesítések miatt.",
+    "Send mode" : "Küldési mód",
+    "Encryption" : "Titkosítás",
+    "Sendmail mode" : "Sendmail mód",
+    "Disable certificate verification (insecure)" : "A tanúsítvány ellenőrzésének letiltása (nem biztonságos)",
+    "From address" : "Feladó címe",
+    "Domain" : "Domain",
+    "Server address" : "Kiszolgáló címe",
+    "Host" : "Kiszolgáló",
+    "Port" : "Port",
+    "Authentication" : "Hitelesítés",
+    "Authentication required" : "Hitelesítés szükséges",
+    "Saving…" : "Mentés…",
+    "Save settings" : "Beállítások mentése",
     "Security & setup warnings" : "Biztonsági és telepítési figyelmeztetések",
     "Try again" : "Próbálja újra",
     "All checks passed." : "Minden ellenőrzés sikeres.",
@@ -550,15 +560,12 @@ OC.L10N.register(
     "App Store" : "Alkalmazástár",
     "Loading app list" : "Alkalmazáslista betöltése",
     "Loading categories" : "Kategóriák betöltése",
-    "Developer documentation ↗" : "Fejlesztői dokumentáció ↗",
     "Version {version}, {license}-licensed" : " {version} verzió,{license} licenc alatt",
     "Apply" : "Alkalmaz",
     "All accounts" : "Összes fiók",
     "Admins" : "Rendszergazdák",
     "Account group: {group}" : "Fiókcsoport: {group}",
     "Account management" : "Fiókkezelés",
-    "Sending…" : "Küldés…",
-    "Email sent" : "E-mail elküldve",
     "Location" : "Hely",
     "Profile picture" : "Profilkép",
     "About" : "Névjegy",
@@ -616,22 +623,6 @@ OC.L10N.register(
     "General documentation" : "Általános dokumentáció",
     "Legal notice" : "Jogi nyilatkozat",
     "Privacy policy" : "Adatvédelmi irányelvek",
-    "None/STARTTLS" : "Semmi/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Dokumentáció megnyitása",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Fontos, hogy a levelezés be legyen állítva a kiszolgálón, például a jelszó-visszaállítások és az értesítések miatt.",
-    "Send mode" : "Küldési mód",
-    "Encryption" : "Titkosítás",
-    "Sendmail mode" : "Sendmail mód",
-    "From address" : "Feladó címe",
-    "Server address" : "Kiszolgáló címe",
-    "Port" : "Port",
-    "Authentication" : "Hitelesítés",
-    "Authentication required" : "Hitelesítés szükséges",
-    "Credentials" : "Hitelesítő adatok",
-    "SMTP Password" : "SMTP jelszó",
-    "Save" : "Mentés",
-    "Test and verify email settings" : "E-mail beállítások tesztelése és ellenőrzése",
     "Reasons to use Nextcloud in your organization" : "Miért használjon Nextcloudot a szervezeténél",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Fejleszti a {communityopen}Nextcloud közösség{linkclose}, a {githubopen}forráskódra{linkclose} az {licenseopen}AGPL{linkclose} licenc vonatkozik.",
     "Like our Facebook page" : "Kedvelje a Facebook oldalunkat",
@@ -639,8 +630,14 @@ OC.L10N.register(
     "Check out our blog" : "Nézze meg a blogunkat",
     "Subscribe to our newsletter" : "Iratkozzon fel a hírlevelünkre",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "A Nextcloud e közösségi kiadása nem támogatott, és az azonnal értesítések nem érhetők el.",
+    "Open documentation" : "Dokumentáció megnyitása",
     "Use a second factor besides your password to increase security for your account." : "Használjon egy második faktort a jelszava mellett, hogy növelje fiókja biztonságát.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ha harmadik féltől származó alkalmazásokat használ a Nextcloudhoz való csatlakozáshoz, akkor a két faktoros hitelesítés engedélyezése előtt győződjön meg róla, hogy mindegyikhez létrehozott és beállított egy alkalmazásjelszót.",
+    "Very weak password" : "Nagyon gyenge jelszó",
+    "Weak password" : "Gyenge jelszó",
+    "So-so password" : "Nem túl jó jelszó",
+    "Good password" : "Jó jelszó",
+    "Strong password" : "Erős jelszó",
     "Group list is empty" : "A csoportlista üres",
     "Unable to retrieve the group list" : "A csoportlista betöltése sikertelen",
     "Logged in account must be a subadmin" : "A belépett felhasználónak al-adminnak kell lennie",
@@ -650,7 +647,16 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Az eszköz elvesztése vagy a szervezetből való kilépés esetén ez távolról képes eltávolítani {userid} minden nextcloudos adatát a hozzá köthető eszközökről: {userid}. Csak akkor működik, ha az eszközök kapcsolódnak az internethez.",
     "Loading account …" : "Felhasználó betöltése...",
     "Adding your device …" : "Eszköz hozzáadása…",
+    "Developer documentation ↗" : "Fejlesztői dokumentáció ↗",
+    "Sending…" : "Küldés…",
+    "Email sent" : "E-mail elküldve",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ez az alkalmazás nincs megjelölve, hogy kompatibilis lenne a jelenlegi Nextcloud verzióval. Ha folytatja, telepítheti az alkalmazást. Azonban az alkalmazás lehet, hogy nem fog rendeltetés szerint működni.",
+    "None/STARTTLS" : "Semmi/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "Hitelesítő adatok",
+    "SMTP Password" : "SMTP jelszó",
+    "Save" : "Mentés",
+    "Test and verify email settings" : "E-mail beállítások tesztelése és ellenőrzése",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "A példánya biztonságához és megfelelő teljesítményéhez fontos, hogy minden beállítás helyes legyen. Ennek érdekében segítünk pár automatikus ellenőrzéssel. További információkért nézze meg a kapcsolódó dokumentációt.",
     "Checking for system and security issues." : "Rendszer- és biztonsági problémák ellenőrzése.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Nézze meg még egyszer a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">telepítési dokumentációt ↗</a>, és keressen hibákat vagy figyelmeztetéseket a <a href=\"%2$s\">naplóban</a>.",
