@@ -197,20 +197,15 @@ OC.L10N.register(
     "Matroska video" : "Matroska-myndskeið",
     "Windows Media video" : "Windows Media myndskeið",
     "AVI video" : "AVI-myndskeið",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
-    "Update to {version}" : "Uppfæra í {version}",
-    "An error occurred." : "Villa átti sér stað.",
-    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppfærslan tókst ekki. Til að fá frekari upplýsingar <a href=\"{url}\">skoðaðu færslu á spjallsvæðinu okkar</a> sem fjallar um þetta mál.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppfærslan tókst ekki. Skoðaðu annálana á kerfisstjórnunarsíðunni og sendu inn tilkynningu um vandamálið til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud samfélagsins</a>.",
-    "Continue to {productName}" : "Halda áfram í {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndu.","Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndur."],
+    "Done" : "Lokið",
     "Applications menu" : "Forritavalmynd",
     "Apps" : "Forrit",
     "More apps" : "Fleiri forrit",
     "_{count} notification_::_{count} notifications_" : ["{count} tilkynning","{count} tilkynningar"],
     "No" : "Nei",
     "Yes" : "Já",
+    "App password" : "Lykilorð forrits",
+    "Grant access" : "Veita aðgengi",
     "The remote URL must include the user." : "Fjartengda vefslóðin þarf að innihalda notandanafnið.",
     "Invalid remote URL." : "Ógild fjartengd slóð.",
     "Failed to add the public link to your Nextcloud" : "Mistókst að bæta opinberum tengli í þitt eigið Nextcloud",
@@ -252,7 +247,6 @@ OC.L10N.register(
     "Log in to {productName}" : "Skrá inn í {productName}",
     "Wrong login or password." : "Rangur notandi eða lykilorð.",
     "This account is disabled" : "Þessi notandaaðgangur er óvirkur",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
     "Account name or email" : "Heiti aðgangs eða tölvupóstfang",
     "Account name" : "Heiti notandaaðgangs",
     "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
@@ -293,13 +287,20 @@ OC.L10N.register(
     "Skip" : "Sleppa",
     "Installing apps …" : "Set upp forrit …",
     "Install recommended apps" : "Setja upp ráðlögð forrit",
+    "Online" : "Á netinu",
+    "Away" : "Fjarverandi",
+    "Busy" : "Upptekinn",
+    "Do not disturb" : "Ekki ónáða",
+    "Mute all notifications" : "Þagga allar tilkynningar",
+    "Invisible" : "Ósýnilegt",
+    "Appear offline" : "Birtast ótengt",
     "Avatar of {displayName}" : "Auðkennismynd fyrir {displayName}",
     "Settings menu" : "Stillingavalmynd",
     "Loading your contacts …" : "Hleð inn tengiliðum …",
     "Looking for {term} …" : "Leita að {term} …",
     "Search contacts" : "Leita í tengiliðum",
-    "Reset search" : "Núllstilla leit",
     "Search contacts …" : "Leita í tengiliðum …",
+    "Reset search" : "Núllstilla leit",
     "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
     "No contacts found" : "Engir tengiliðir fundust",
     "Show all contacts" : "Birta alla tengiliði ...",
@@ -317,12 +318,29 @@ OC.L10N.register(
     "Back" : "Til baka",
     "Login form is disabled." : "Innskráningarform er óvirkt.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Innskráningarform Nextcloud er óvirkt. Notaðu aðra aðferð til innskráningar ef slíkt er í boði eða hafðu samband við kerfisstjórnanda.",
+    "Connect to your account" : "Tengdu við notandaaðganginn þinn",
+    "Security warning" : "Öryggisviðvörun",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ef þú ert ekki að reyna að setja upp nýtt tæki eða forrit, þá er einhver annar að reyna að gabba þig til að gefa þeim aðgang að gögnunum þínum. Ef svo er, skaltu ekki halda áfram í þessu ferli og hafa strax samband við kerfisstjórann þinn.",
+    "Alternative log in using app password" : "Önnur innskráning með lykilorði forrits",
+    "Account connected" : "Aðgangur er tengdur",
+    "Your client should now be connected!" : "Biðlaraforritið þitt ætti núna að vera tengt!",
+    "You can close this window." : "Þú mátt loka þessum glugga.",
+    "Account access" : "Aðgangur að notandaaðgangi",
     "More actions" : "Fleiri aðgerðir",
     "User menu" : "Valmynd notandans",
     "Your guest name: {user}" : "Gestanafnið þitt: {user}",
     "You are currently not identified." : "Þú ert ekki auðkennd/ur.",
     "Set public name" : "Setja opinbert nafn",
     "Change public name" : "Breyta opinberu nafni",
+    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
+    "The password is wrong or expired. Please try again or request a new one." : "Lykilorðið er rangt eða útrunnið. Prófaðu aftur eða biddu um nýtt lykilorð.",
+    "Submit" : "Senda inn",
+    "Please type in your email address to request a temporary password" : "Settu inn tölvupóstfangið þitt til að biðja um bráðabirgðalykilorð",
+    "Password sent!" : "Lykilorð sent!",
+    "You are not authorized to request a password for this share" : "Þú hefur ekki heimild til að biðja um lykilorð fyrir þessa sameign",
+    "Email address" : "Tölvupóstfang",
+    "Request password" : "Biðja um lykilorð",
+    "Forgot password" : "Gleymdi lykilorði",
     "Password is too weak" : "Lykilorð er of veikt",
     "Password is weak" : "Lykilorð er veikt",
     "Password is average" : "Lykilorð er í meðallagi",
@@ -334,7 +352,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Til að fá upplýsingar hvernig á að stilla miðlara almennilega, skaltu skoða {linkStart}hjálparskjölin{linkEnd}",
     "Autoconfig file detected" : "Fann autoconfig-uppsetningarskrá",
     "The setup form below is pre-filled with the values from the config file." : "Uppsetningrformið hér fyrir neðan er for-útfyllt með gildunum í config-skránni.",
-    "Security warning" : "Öryggisviðvörun",
     "Create administration account" : "Búa til stjórnunaraðgang",
     "Administration account name" : "Heiti kerfisstjóraaðgangs",
     "Administration account password" : "Lykilorð kerfisstjóraaðgangs",
@@ -364,6 +381,22 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Það er ekki stuðningur við vafrann þinn. Endilega uppfærðu í nýrri útgáfu eða vafra sem er studdur.",
     "Continue with this unsupported browser" : "Halda áfram með þessum óstudda vafra",
     "Supported versions" : "Studdar útgáfur",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
+    "App update required" : "App þarfnast uppfærslu ",
+    "These incompatible apps will be disabled:" : "Eftirfarandi forrit eru ósamhæfð og verið gerð óvirk: %s",
+    "These apps will be updated:" : "Eftirfarandi öpp verða uppfærð:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gakktu úr skugga um að gagnagrunnurinn, config mappan og gagnamappan hafi verið öryggisafritaðar áður en lengra er haldið.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
+    "Start update" : "Hefja uppfærslu",
+    "Continue to {productName}" : "Halda áfram í {productName}",
+    "Update to {version}" : "Uppfæra í {version}",
+    "Hide details" : "Fela nánari upplýsingar",
+    "Show details" : "Birta nánari upplýsingar",
+    "Update needed" : "Þarfnast uppfærslu",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu með fleiri en 50 notendaaðgöngum.",
+    "Documentation" : "Leiðbeiningar",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ég veit að ef ég held uppfærslunni áfram í gegnum vefviðmótið, þá er sú áhætta fyrir hendi að beiðnin falli á tímamörkum, sem aftur gæti valdið gagnatapi - en ég á öryggisafrit og veit hvernig ég get endurheimt uppsetninguna mína ef aðgerðin misferst.",
+    "Upgrade via web on my own risk" : "Uppfæra með vefviðmóti á mína eigin ábyrgð",
     "Search {types} …" : "Leita að {types} …",
     "Choose {file}" : "Veldu {file}",
     "Choose" : "Veldu",
@@ -385,20 +418,17 @@ OC.L10N.register(
     "({count} selected)" : "({count} valið)",
     "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
     "Saving …" : "Vista …",
+    "Groups" : "Hópar",
+    "Group list is empty" : "Listi yfir hópa er tómur",
+    "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
     "seconds ago" : "sekúndum síðan",
-    "Connection to server lost" : "Tenging við miðlara rofnaði",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
     "Add to a project" : "Bæta við verkefni",
-    "Show details" : "Birta nánari upplýsingar",
-    "Hide details" : "Fela nánari upplýsingar",
     "Rename project" : "Endurnefna verkefni",
     "Failed to rename the project" : "Mistókst að endurnefna verkefnið",
     "Failed to create a project" : "Mistókst að útbúa verkefni",
     "Failed to add the item to the project" : "Mistókst að bæta atriðinu í verkefnið",
     "Connect items to a project to make them easier to find" : "Að tengja atriði við verkefni gerir auðveldara að finna þau",
     "Type to search for existing projects" : "Skrifaðu hér til að leita að fyrirliggjandi verkefnum",
-    "New in" : "Nýtt í",
-    "View changelog" : "Skoða breytingaannál",
     "Close \"{dialogTitle}\" dialog" : "Loka \"{dialogTitle}\"-glugga",
     "Email length is at max (255)" : "Lengd tölvupósts er að hámarki (255)",
     "Clipboard not available, please copy manually" : "Klippispjald er ekki tiltækt, afritaðu handvirkt",
@@ -435,25 +465,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Hlaupa yfir í flakk innan forrits",
     "Go to %s" : "Farðu í %s",
     "Get your own free account" : "Fáðu þér eigin ókeypis aðgang",
-    "Connect to your account" : "Tengdu við notandaaðganginn þinn",
-    "Please log in before granting %1$s access to your %2$s account." : "Skráðu þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ef þú ert ekki að reyna að setja upp nýtt tæki eða forrit, þá er einhver annar að reyna að gabba þig til að gefa þeim aðgang að gögnunum þínum. Ef svo er, skaltu ekki halda áfram í þessu ferli og hafa strax samband við kerfisstjórann þinn.",
-    "App password" : "Lykilorð forrits",
-    "Grant access" : "Veita aðgengi",
-    "Alternative log in using app password" : "Önnur innskráning með lykilorði forrits",
-    "Account access" : "Aðgangur að notandaaðgangi",
-    "Currently logged in as %1$s (%2$s)." : "Í augnablikinu er skráð inn sem %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
-    "Account connected" : "Aðgangur er tengdur",
-    "Your client should now be connected!" : "Biðlaraforritið þitt ætti núna að vera tengt!",
-    "You can close this window." : "Þú mátt loka þessum glugga.",
     "Previous" : "Fyrra",
-    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
-    "The password is wrong or expired. Please try again or request a new one." : "Lykilorðið er rangt eða útrunnið. Prófaðu aftur eða biddu um nýtt lykilorð.",
-    "Please type in your email address to request a temporary password" : "Settu inn tölvupóstfangið þitt til að biðja um bráðabirgðalykilorð",
-    "Email address" : "Tölvupóstfang",
-    "Password sent!" : "Lykilorð sent!",
-    "You are not authorized to request a password for this share" : "Þú hefur ekki heimild til að biðja um lykilorð fyrir þessa sameign",
     "Two-factor authentication" : "Tveggja-þrepa auðkenning",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu aukaþrep til auðkenningar:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Gat ekki hlaðið inn a.m.k. einni af virkum tveggja-þrepa auðkenningaraðferðunum þínum. Hafðu samband við kerfisstjóra.",
@@ -468,20 +480,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Tenging frá ótreystu léni",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %1$shjálparskjölunum%2$s.",
-    "App update required" : "App þarfnast uppfærslu ",
-    "%1$s will be updated to version %2$s" : "%1$s verður uppfært í útgáfu %2$s.",
-    "The following apps will be updated:" : "Eftirfarandi forrit verða uppfærð:",
-    "These incompatible apps will be disabled:" : "Eftirfarandi forrit eru ósamhæfð og verið gerð óvirk: %s",
-    "The theme %s has been disabled." : "Þema %s hefur verið gert óvirkt.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gakktu úr skugga um að gagnagrunnurinn, config mappan og gagnamappan hafi verið öryggisafritaðar áður en lengra er haldið.",
-    "Start update" : "Hefja uppfærslu",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
-    "Detailed logs" : "Ítarlegar atvikaskrár",
-    "Update needed" : "Þarfnast uppfærslu",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu með fleiri en 50 notendaaðgöngum.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hjálparskjölin</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ég veit að ef ég held uppfærslunni áfram í gegnum vefviðmótið, þá er sú áhætta fyrir hendi að beiðnin falli á tímamörkum, sem aftur gæti valdið gagnatapi - en ég á öryggisafrit og veit hvernig ég get endurheimt uppsetninguna mína ef aðgerðin misferst.",
-    "Upgrade via web on my own risk" : "Uppfæra með vefviðmóti á mína eigin ábyrgð",
     "Maintenance mode" : "Viðhaldshamur",
     "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
     "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
@@ -496,22 +494,27 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hér eru leitarniðurstöðurnar þínar<script>alert(1)</script></strong>",
     "new" : "nýtt",
     "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
+    "An error occurred." : "Villa átti sér stað.",
+    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppfærslan tókst ekki. Til að fá frekari upplýsingar <a href=\"{url}\">skoðaðu færslu á spjallsvæðinu okkar</a> sem fjallar um þetta mál.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppfærslan tókst ekki. Skoðaðu annálana á kerfisstjórnunarsíðunni og sendu inn tilkynningu um vandamálið til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud samfélagsins</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndu.","Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndur."],
+    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald",
     "Searching …" : "Leita …",
     "Logging in …" : "Skrái inn …",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
     "Loading apps …" : "Hleð inn forritum …",
     "Installing apps …" : "Set upp forrit …",
     "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
     "Looking for {term} …" : "Leita að {term} …",
     "Search contacts …" : "Leita í tengiliðum ",
     "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
-    "You have not added any info yet" : "Þú hefur ekki bætt við neinum upplýsingum ennþá",
-    "{user} has not added any info yet" : "{user} hefur ekki bætt við neinum upplýsingum ennþá",
-    "Error opening the user status modal, try hard refreshing the page" : "Villa við að opna stöðuglugga notandans, prófaðu að þvinga endurlestur síðunnar",
-    "Edit Profile" : "Breyta sniði",
-    "The headline and about sections will show up here" : "Fyrirsögnin og hlutar um hugbúnaðinn munu birtast hér",
     "Search {types} …" : "Leita að {types} …",
     "Saving …" : "Vista …",
+    "Connection to server lost" : "Tenging við miðlara rofnaði",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
+    "New in" : "Nýtt í",
+    "View changelog" : "Skoða breytingaannál",
     "Very weak password" : "Mjög veikt lykilorð",
     "Weak password" : "Veikt lykilorð",
     "So-so password" : "Miðlungs lykilorð",
@@ -521,13 +524,10 @@ OC.L10N.register(
     "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
     "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
     "Restricted" : "Takmarkað",
-    "Invisible" : "Ósýnilegt",
     "Delete" : "Eyða",
     "Rename" : "Endurnefna",
     "Collaborative tags" : "Samstarfsmerkingar",
     "No tags found" : "Engin merki fundust",
-    "Profile not found" : "Sniðið finnst ekki",
-    "The profile does not exist." : "Sniðið er ekki til.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Útbúa kerfisstjóraaðgang</strong>",
@@ -539,6 +539,13 @@ OC.L10N.register(
     "Only %s is available." : "Aðeins %s eru laus.",
     "Database account" : "Gagnagrunnsaðgangur",
     "Installing …" : "Set upp…",
-    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald"
+    "Please log in before granting %1$s access to your %2$s account." : "Skráðu þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
+    "Currently logged in as %1$s (%2$s)." : "Í augnablikinu er skráð inn sem %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
+    "%1$s will be updated to version %2$s" : "%1$s verður uppfært í útgáfu %2$s.",
+    "The following apps will be updated:" : "Eftirfarandi forrit verða uppfærð:",
+    "The theme %s has been disabled." : "Þema %s hefur verið gert óvirkt.",
+    "Detailed logs" : "Ítarlegar atvikaskrár",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hjálparskjölin</a>."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
