@@ -65,14 +65,6 @@ OC.L10N.register(
     "Already up to date" : "Naudojama naujausia versija",
     "Unknown" : "Nežinoma",
     "PNG image" : "PNG paveikslas",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Vykdomas atnaujinimas, palikus šį puslapį atvertą, kai kuriose aplinkose šis procesas gali būti nutrauktas.",
-    "Update to {version}" : "Atnaujinti į versiją {version}",
-    "An error occurred." : "Įvyko klaida.",
-    "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atnaujinimas buvo nesėkmingas. Išsamesnei informacijai apie šią problemą, <a href=\"{url}\">žiūrėkite įrašą mūsų forume</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
-    "Continue to {productName}" : "Tęsti {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n seconds.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sekundes."],
     "Done" : "Atlikta",
     "Applications menu" : "Programų meniu",
     "Apps" : "Programėlės",
@@ -154,6 +146,12 @@ OC.L10N.register(
     "You can close this window." : "Galite užverti šį langą.",
     "Account access" : "Paskyros prieiga",
     "More actions" : "Daugiau veiksmų",
+    "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
+    "Submit" : "Pateikti",
+    "Password sent!" : "Slaptažodis išsiųstas!",
+    "Email address" : "El. pašto adresas",
+    "Request password" : "Prašyti slaptažodžio",
+    "Forgot password" : "Pamiršau slaptažodį",
     "Storage & database" : "Saugykla ir duomenų bazė",
     "Data folder" : "Duomenų aplankas",
     "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
@@ -174,6 +172,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Jūsų naršyklė yra nepalaikoma. Atnaujinkite į naujesnę versiją arba naudokite palaikomą naršyklę.",
     "Continue with this unsupported browser" : "Tęsti naudojant šią nepalaikomą naršyklę",
     "Supported versions" : "Palaikomos versijos",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Vykdomas atnaujinimas, palikus šį puslapį atvertą, kai kuriose aplinkose šis procesas gali būti nutrauktas.",
+    "App update required" : "Reikalingas programėlės atnaujinimas",
+    "These incompatible apps will be disabled:" : "Bus išjungtos šios nesuderinamos programėlės:",
+    "These apps will be updated:" : "Bus atnaujintos šios programėlės:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prieš tęsdami, įsitikinkite, kad pasidarėte duomenų bazės, konfigūracijos aplanko bei duomenų aplanko atsarginę kopiją.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Naudodami didesnius diegimus ir norėdami išvengti laukimo laiko, vietoj to, savo diegimo kataloge galite paleisti šią komandą:",
+    "Start update" : "Pradėti atnaujinimą",
+    "Continue to {productName}" : "Tęsti {productName}",
+    "Update to {version}" : "Atnaujinti į versiją {version}",
+    "Hide details" : "Slėpti išsamesnę informaciją",
+    "Show details" : "Rodyti išsamiau",
+    "Update needed" : "Reikalingas atnaujinimas",
+    "Documentation" : "Dokumentacija",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Suprantu, kad atnaujinimui naudodamas vartotojo aplinką, rizikuoju, kad sistemos darbas sutriks ir prisijungę vartotojai gali netekti duomenų, turiu atsarginę duomenų kopiją ir žinau, kaip atstatyti duomenis nesėkmės atveju.",
+    "Upgrade via web on my own risk" : "Atnaujinti per interneto naršyklę prisiimant riziką",
     "Choose {file}" : "Pasirinkti{file}",
     "Choose" : "Pasirinkti",
     "Copy to {target}" : "Kopijuoti į {target}",
@@ -198,19 +211,13 @@ OC.L10N.register(
     "Group list is empty" : "Grupės sąrašas yra tuščias",
     "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
     "seconds ago" : "prieš keletą sekundžių",
-    "Connection to server lost" : "Ryšys su serveriu nutrūko",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
     "Add to a project" : "Pridėti į projektą",
-    "Show details" : "Rodyti išsamiau",
-    "Hide details" : "Slėpti išsamesnę informaciją",
     "Rename project" : "Pervadinti projektą",
     "Failed to rename the project" : "Nepavyko pervadinti projekto",
     "Failed to create a project" : "Nepavyko sukurti projekto",
     "Failed to add the item to the project" : "Nepavyko pridėti elemento į projektą",
     "Connect items to a project to make them easier to find" : "Susieti elementus su projektu, kad juos būtų lengviau rasti",
     "Type to search for existing projects" : "Rašykite norėdami ieškoti esamų projektų",
-    "New in" : "Nauja",
-    "View changelog" : "Rodyti keitinių žurnalą",
     "Personal" : "Asmeniniai",
     "Accounts" : "Paskyros",
     "Admin" : "Administravimas",
@@ -242,9 +249,6 @@ OC.L10N.register(
     "Go to %s" : "Pereiti į %s",
     "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
     "Previous" : "Ankstesnis",
-    "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
-    "Email address" : "El. pašto adresas",
-    "Password sent!" : "Slaptažodis išsiųstas!",
     "Two-factor authentication" : "Dviejų faktorių tapatybės nustatymas",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nepavyko įkelti bent vieno iš jūsų įjungtų dviejų faktorių tapatybės nustatymo metodų. Susisiekite su savo administratoriumi.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Susisiekite su savo administratoriumi dėl pagalbos. ",
@@ -256,19 +260,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Prieiga iš nepatikimo domeno",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Susisiekite su savo administratoriumi. Jeigu jūs esate administratorius, pataisykite \"trusted_domains\" nustatymą config/config.php faile, kaip tai parodyta pavyzdyje, config.sample.php faile.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Tolimesnę informaciją apie tai, kaip tai konfigūruoti, galite rasti %1$sdokumentacijoje%2$s.",
-    "App update required" : "Reikalingas programėlės atnaujinimas",
-    "%1$s will be updated to version %2$s" : "%1$s bus atnaujinta į versiją %2$s",
-    "The following apps will be updated:" : "Bus atnaujintos šios programėlės:",
-    "These incompatible apps will be disabled:" : "Bus išjungtos šios nesuderinamos programėlės:",
-    "The theme %s has been disabled." : "Apipavidalinimas %s buvo išjungtas.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prieš tęsdami, įsitikinkite, kad pasidarėte duomenų bazės, konfigūracijos aplanko bei duomenų aplanko atsarginę kopiją.",
-    "Start update" : "Pradėti atnaujinimą",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Naudodami didesnius diegimus ir norėdami išvengti laukimo laiko, vietoj to, savo diegimo kataloge galite paleisti šią komandą:",
-    "Detailed logs" : "Išsamūs žurnalai",
-    "Update needed" : "Reikalingas atnaujinimas",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Prireikus pagalbos, žiūrėkite  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Suprantu, kad atnaujinimui naudodamas vartotojo aplinką, rizikuoju, kad sistemos darbas sutriks ir prisijungę vartotojai gali netekti duomenų, turiu atsarginę duomenų kopiją ir žinau, kaip atstatyti duomenis nesėkmės atveju.",
-    "Upgrade via web on my own risk" : "Atnaujinti per interneto naršyklę prisiimant riziką",
     "Maintenance mode" : "Techninės priežiūros veiksena",
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
     "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
@@ -283,6 +274,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
     "new" : "naujas",
     "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
+    "An error occurred." : "Įvyko klaida.",
+    "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atnaujinimas buvo nesėkmingas. Išsamesnei informacijai apie šią problemą, <a href=\"{url}\">žiūrėkite įrašą mūsų forume</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n seconds.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sekundes."],
     "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
     "Searching …" : "Ieškoma…",
     "Logging in …" : "Prisijungiama …",
@@ -295,6 +291,10 @@ OC.L10N.register(
     "Loading more results …" : "Įkeliama daugiau rezultatų…",
     "Search {types} …" : "Ieškoti {types}…",
     "Saving …" : "Įrašoma…",
+    "Connection to server lost" : "Ryšys su serveriu nutrūko",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
+    "New in" : "Nauja",
+    "View changelog" : "Rodyti keitinių žurnalą",
     "Very weak password" : "Labai silpnas slaptažodis",
     "Weak password" : "Silpnas slaptažodis",
     "So-so password" : "Neblogas slaptažodis",
@@ -318,6 +318,11 @@ OC.L10N.register(
     "Installing …" : "Įdiegiama…",
     "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
     "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros."
+    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
+    "%1$s will be updated to version %2$s" : "%1$s bus atnaujinta į versiją %2$s",
+    "The following apps will be updated:" : "Bus atnaujintos šios programėlės:",
+    "The theme %s has been disabled." : "Apipavidalinimas %s buvo išjungtas.",
+    "Detailed logs" : "Išsamūs žurnalai",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Prireikus pagalbos, žiūrėkite  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją</a>."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
