@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Nieznany typ pliku",
     "An error occurred. Please contact your admin." : "Wystąpił błąd. Skontaktuj się z administratorem.",
     "Invalid image" : "Nieprawidłowy obraz",
-    "No temporary profile picture available, try again" : "Brak tymczasowego zdjęcia profilowego, spróbuj ponownie",
-    "No crop data provided" : "Brak danych do przycięcia",
-    "No valid crop data provided" : "Brak prawidłowych danych do przycięcia",
-    "Crop is not square" : "Przycięcie nie jest kwadratowe",
     "State token does not match" : "Token nie pasuje",
     "Invalid app password" : "Nieprawidłowe hasło do aplikacji",
     "Could not complete login" : "Nie można dokończyć logowania",
@@ -46,13 +42,17 @@ OC.L10N.register(
     "Not found" : "Nie znaleziono",
     "Node is locked" : "Węzeł jest zablokowany",
     "Bad request" : "Złe żądanie",
+    "Input text is too long" : "Wprowadzony tekst jest zbyt długi",
     "Requested task type does not exist" : "Żądany typ zadania nie istnieje",
     "Necessary language model provider is not available" : "Niezbędny dostawca modelu językowego nie jest dostępny",
+    "Cannot generate more than 12 images" : "Nie można wygenerować więcej niż 12 obrazów",
+    "Cannot generate less than 1 image" : "Nie można wygenerować mniej niż 1 obraz",
     "No text to image provider is available" : "Brak dostępnego dostawcy tekstu na obraz",
     "Image not found" : "Nie znaleziono obrazu",
     "No translation provider available" : "Brak dostępnego dostawcy tłumaczenia",
     "Could not detect language" : "Nie można wykryć języka",
     "Unable to translate" : "Nie można przetłumaczyć",
+    "No valid filters provided" : "Nie podano prawidłowych filtrów",
     "[%d / %d]: %s" : "[%d/%d]: %s",
     "Repair step:" : "Krok naprawy:",
     "Repair info:" : "Informacja o naprawie: ",
@@ -200,28 +200,18 @@ OC.L10N.register(
     "Matroska video" : "Wideo Matroska",
     "Windows Media video" : "Wideo Windows Media",
     "AVI video" : "Wideo AVI",
-    "unknown text" : "nieznany tekst",
-    "Hello world!" : "Witaj świecie!",
-    "sunny" : "słoneczna",
-    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
-    "Hello {name}" : "Witaj {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To są twoje wyniki wyszukiwania<script>alert(1)</script></strong>",
-    "new" : "nowy",
-    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n pliki","pobrano %n plików","pobrano %n plików"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Trwa aktualizacja. W niektórych przypadkach, opuszczenie tej strony może przerwać ten proces.",
-    "Update to {version}" : "Aktualizacja do {version}",
-    "An error occurred." : "Wystąpił błąd.",
-    "Please reload the page." : "Przeładuj stronę.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizacja nie powiodła się. Aby uzyskać więcej informacji, <a href=\"{url}\">zapoznaj się z naszym postem na forum</a> dotyczącym tego problemu.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizacja nie powiodła się. Zgłoś ten problem do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">społeczności Nextcloud</a>.",
-    "Continue to {productName}" : "Przejdź do {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundę.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundy.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund."],
+    "Done" : "Gotowe",
+    "Scan QR code to log in" : "Zeskanuj kod QR, aby się zalogować",
+    "Use {productName} mobile client you want to connect to scan the code" : "Użyj klienta mobilnego {productName}, z którym chcesz się połączyć, aby zeskanować kod",
+    "Code will expire {timeCountdown} or after use" : "Kod wygaśnie za {timeCountdown} lub po użyciu",
     "Applications menu" : "Menu aplikacji",
     "Apps" : "Aplikacje",
     "More apps" : "Więcej aplikacji",
     "_{count} notification_::_{count} notifications_" : ["{count} powiadomienie","{count} powiadomienia","{count} powiadomień","{count} powiadomień"],
     "No" : "Nie",
     "Yes" : "Tak",
+    "App password" : "Hasło aplikacji",
+    "Grant access" : "Udziel dostępu",
     "The remote URL must include the user." : "Zdalny adres URL musi zawierać nazwę użytkownika.",
     "Invalid remote URL." : "Nieprawidłowy zdalny adres URL.",
     "Failed to add the public link to your Nextcloud" : "Nie udało się dodać linku publicznego do Nextcloud",
@@ -237,14 +227,16 @@ OC.L10N.register(
     "Search in current app" : "Wyszukaj w bieżącej aplikacji",
     "Clear search" : "Wyczyść wyszukiwanie",
     "Search everywhere" : "Szukaj wszędzie",
-    "Searching …" : "Wyszukiwanie…",
+    "Searching …" : "Wyszukiwanie …",
     "Start typing to search" : "Zacznij pisać, aby wyszukać",
+    "Minimum search length is {minSearchLength} characters" : "Minimalna długość wyszukiwania to {minSearchLength} znaków",
     "No matching results" : "Brak pasujących wyników",
     "Today" : "Dzisiaj",
     "Last 7 days" : "Ostatnie 7 dni",
     "Last 30 days" : "Ostatnie 30 dni",
     "This year" : "W tym roku",
     "Last year" : "W zeszłym roku",
+    "Between {startDate} and {endDate}" : "Pomiędzy {startDate} a {endDate}",
     "Unified search" : "Ujednolicone wyszukiwanie",
     "Search apps, files, tags, messages" : "Szukaj aplikacji, plików, tagów, wiadomości",
     "Places" : "Miejsca",
@@ -256,12 +248,13 @@ OC.L10N.register(
     "Results" : "Wyniki",
     "Load more results" : "Wczytaj więcej wyników",
     "Search in" : "Szukaj w",
+    "Partial matches" : "Częściowe dopasowania",
     "Log in" : "Zaloguj",
-    "Logging in …" : "Logowanie…",
+    "Logging in …" : "Logowanie ...",
     "Log in to {productName}" : "Zaloguj się do {productName}",
     "Wrong login or password." : "Błędny login lub hasło.",
     "This account is disabled" : "To konto jest wyłączone",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Wykryliśmy wiele nieudanych prób logowania z Twojego adresu IP. Dlatego następne logowanie będzie możliwe dopiero za 30 sekund.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Zbyt wiele nieprawidłowych prób logowania. Spróbuj ponownie za 30 sekund.",
     "Account name or email" : "Nazwa konta lub e-mail",
     "Account name" : "Nazwa konta",
     "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
@@ -271,6 +264,7 @@ OC.L10N.register(
     "An internal error occurred." : "Wystąpił błąd wewnętrzny.",
     "Please try again or contact your administrator." : "Spróbuj ponownie lub skontaktuj się z administratorem.",
     "Password" : "Hasło",
+    "Remember me" : "Zapamiętaj mnie",
     "Log in with a device" : "Zaloguj się za pomocą urządzenia",
     "Login or email" : "Nazwa logowania lub e-mail",
     "Your account is not setup for passwordless login." : "Twoje konto nie jest skonfigurowane do logowania bez hasła.",
@@ -294,23 +288,34 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Wspólne dokumenty, arkusze kalkulacyjne i prezentacje oparte na Collabora Online.",
     "Distraction free note taking app." : "Aplikacja do robienia notatek bez rozpraszania uwagi.",
     "Recommended apps" : "Polecane aplikacje",
-    "Loading apps …" : "Wczytywanie aplikacji…",
+    "Loading apps …" : "Wczytywanie aplikacji …",
     "Could not fetch list of apps from the App Store." : "Nie można pobrać listy aplikacji ze sklepu z aplikacjami.",
     "App download or installation failed" : "Pobieranie lub instalacja aplikacji nie powiodła się",
     "Cannot install this app because it is not compatible" : "Nie można zainstalować tej aplikacji, ponieważ nie jest kompatybilna",
     "Cannot install this app" : "Nie można zainstalować tej aplikacji",
     "Skip" : "Pomiń",
-    "Installing apps …" : "Instalowanie aplikacji…",
+    "Installing apps …" : "Instalowanie aplikacji …",
     "Install recommended apps" : "Zainstaluj zalecane aplikacje",
+    "Online" : "Online",
+    "Away" : "Bezczynny",
+    "Busy" : "Brak dostępności",
+    "Do not disturb" : "Nie przeszkadzać",
+    "Mute all notifications" : "Wycisz wszystkie powiadomienia",
+    "Invisible" : "Niewidoczny",
+    "Appear offline" : "Wyglądaj jako offline",
     "Avatar of {displayName}" : "Awatar {displayName}",
     "Settings menu" : "Menu ustawień",
-    "Loading your contacts …" : "Wczytywanie kontaktów…",
-    "Looking for {term} …" : "Szukam {term}…",
+    "Loading your contacts …" : "Wczytywanie kontaktów …",
+    "Looking for {term} …" : "Szukam {term} …",
     "Search contacts" : "Szukaj kontaktów",
+    "Filter by team" : "Filtruj według zespołu",
+    "All teams" : "Wszystkie zespoły",
+    "Search contacts in team {team}" : "Szukaj kontaktów w zespole {team}",
+    "Search contacts …" : "Wyszukiwanie kontaktów …",
     "Reset search" : "Zresetuj wyszukiwanie",
-    "Search contacts …" : "Wyszukiwanie kontaktów…",
     "Could not load your contacts" : "Nie można wczytać kontaktów",
     "No contacts found" : "Nie znaleziono kontaktów",
+    "Contacts list" : "Lista kontaktów",
     "Show all contacts" : "Pokaż wszystkie kontakty",
     "Install the Contacts app" : "Zainstaluj aplikację \"Kontakty\"",
     "Search" : "Szukaj",
@@ -320,18 +325,39 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Wystąpił błąd podczas wyszukiwania {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Wyszukiwanie rozpoczyna się po rozpoczęciu pisania, a wyniki można uzyskać za pomocą klawiszy strzałek",
     "Search for {name} only" : "Wyszukaj tylko {name}",
-    "Loading more results …" : "Wczytuję więcej wyników…",
+    "Loading more results …" : "Wczytuję więcej wyników …",
     "Forgot password?" : "Zapomniałeś hasła?",
     "Back to login form" : "Powrót do formularza logowania",
     "Back" : "Wstecz",
     "Login form is disabled." : "Formularz logowania jest wyłączony.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Formularz logowania Nextcloud jest wyłączony. Użyj innej opcji logowania, jeśli jest dostępna, lub skontaktuj się z administracją.",
+    "Connect to your account" : "Połącz z kontem",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Zaloguj się, zanim przyznasz klientowi \"{client}\" dostęp do konta {instanceName}.",
+    "Security warning" : "Ostrzeżenie bezpieczeństwa",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeśli nie konfigurujesz nowego urządzenia lub aplikacji, to wynika z tego, że ktoś próbuje, abyś udzielił dostępu do Twoich danych. W takim przypadku nie kontynuuj, tylko skontaktuj się z administratorem systemu.",
+    "Log in using password" : "Zaloguj się przy użyciu hasła",
+    "Alternative log in using app password" : "Alternatywne logowanie przy użyciu hasła do aplikacji",
+    "Account connected" : "Połączono z kontem",
+    "Your client should now be connected!" : "Twój klient powinien być teraz podłączony!",
+    "You can close this window." : "Możesz zamknąć to okno.",
+    "Account access" : "Dostęp do konta",
+    "Currently logged in as {userDisplayName} ({userId})." : "Aktualnie zalogowany jako {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Zamierzasz przyznać klientowi \"{client}\" dostęp do konta {instanceName}.",
     "More actions" : "Więcej akcji",
     "User menu" : "Menu użytkownika",
     "Your guest name: {user}" : "Twoja nazwa gościa: {user}",
     "You are currently not identified." : "Obecnie nie jesteś zidentyfikowany.",
     "Set public name" : "Ustaw nazwę publiczną",
     "Change public name" : "Zmień nazwę publiczną",
+    "This share is password-protected" : "Udostępnienie jest zabezpieczone hasłem",
+    "The password is wrong or expired. Please try again or request a new one." : "Hasło jest nieprawidłowe lub wygasło. Spróbuj ponownie lub poproś o nowe.",
+    "Submit" : "Wyślij",
+    "Please type in your email address to request a temporary password" : "Wpisz swój adres e-mail, aby poprosić o tymczasowe hasło",
+    "Password sent!" : "Hasło wysłane!",
+    "You are not authorized to request a password for this share" : "Nie masz uprawnień do żądania hasła dla tego udostępnienia",
+    "Email address" : "Adres e-mail",
+    "Request password" : "Żądanie hasła",
+    "Forgot password" : "Zapomniałeś hasła?",
     "Password is too weak" : "Hasło jest za słabe",
     "Password is weak" : "Hasło jest słabe",
     "Password is average" : "Hasło jest przeciętne",
@@ -343,13 +369,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Aby uzyskać informacje na temat prawidłowej konfiguracji serwera, {linkStart}zapoznaj się z dokumentacją{linkEnd}",
     "Autoconfig file detected" : "Wykryto plik autokonfiguracjny",
     "The setup form below is pre-filled with the values from the config file." : "Poniższy formularz konfiguracji jest wstępnie wypełniony wartościami z pliku konfiguracyjnego.",
-    "Security warning" : "Ostrzeżenie bezpieczeństwa",
     "Create administration account" : "Utwórz konto administracyjne",
     "Administration account name" : "Nazwa konta administracyjnego",
     "Administration account password" : "Hasło do konta administracyjnego",
     "Storage & database" : "Magazyn i baza danych",
     "Data folder" : "Katalog danych",
     "Database configuration" : "Konfiguracja bazy danych",
+    "Database type" : "Typ bazy danych",
     "Only {firstAndOnlyDatabase} is available." : "Dostępne jest tylko {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Zainstaluj lub aktywuj dodatkowe moduły PHP, aby uzyskać możliwość wyboru innych typów baz danych.",
     "For more details check out the documentation." : "Aby uzyskać więcej informacji zapoznaj się z dokumentacją.",
@@ -357,6 +383,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Wybrałeś SQLite jako bazę danych.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite powinien być używany tylko dla instancji minimalnych i rozwojowych. Dla rozwiniętej zalecamy inne zaplecze bazy danych.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jeśli używasz klientów do synchronizacji plików, używanie SQLite jest bardzo odradzane.",
+    "Database connection" : "Połączenie bazy danych",
     "Database user" : "Użytkownik bazy danych",
     "Database password" : "Hasło do bazy danych",
     "Database name" : "Nazwa bazy danych",
@@ -364,7 +391,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Podaj numer portu wraz z nazwą hosta (np. localhost: 5432).",
     "Database host" : "Host bazy danych",
     "localhost" : "localhost",
-    "Installing …" : "Instalowanie…",
+    "Installing …" : "Instalowanie …",
     "Install" : "Zainstaluj",
     "Need help?" : "Potrzebujesz pomocy?",
     "See the documentation" : "Zapoznaj się z dokumentacją",
@@ -373,7 +400,33 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Twoja przeglądarka nie jest wspierana. Uaktualnij do nowszej lub obsługiwanej wersji.",
     "Continue with this unsupported browser" : "Kontynuuj w tej nieobsługiwanej przeglądarce",
     "Supported versions" : "Obsługiwane wersje",
-    "Search {types} …" : "Wyszukaj {types}…",
+    "The update completed with warnings. Please check the details for more information." : "Aktualizacja zakończona z ostrzeżeniami. Sprawdź szczegóły, aby uzyskać więcej informacji.",
+    "The update completed successfully." : "Aktualizacja zakończona pomyślnie.",
+    "Preparing update…" : "Przygotowywanie aktualizacji…",
+    "You will be redirected to {productName} in {count} seconds." : "Za {count} sekund nastąpi przekierowanie do {productName}",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Trwa aktualizacja. W niektórych przypadkach, opuszczenie tej strony może przerwać ten proces.",
+    "App update required" : "Wymagana aktualizacja aplikacji",
+    "{productName} will be updated to version {version}" : "{productName} zostanie zaktualizowany do wersji {version}",
+    "The theme {oldTheme} has been disabled." : "Motyw {oldTheme} został wyłączony.",
+    "These incompatible apps will be disabled:" : "Niekompatybilne aplikacje zostaną wyłączone:",
+    "Incompatible apps" : "Niekompatybilne aplikacje",
+    "These apps will be updated:" : "Następujące aplikacje zostaną zaktualizowane:",
+    "Apps to update" : "Aplikacje do aktualizacji",
+    "{app} from {oldVersion} to {version}" : "{app} z {oldVersion} do {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Przed kontynuowaniem upewnij się, że utworzono kopię zapasową bazy danych, katalogu konfiguracyjnego i katalogu danych.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "W przypadku większych instalacji, aby uniknąć przekroczenia limitu czasu, możesz zamiast tego instalatora uruchomić następujące polecenie z katalogu instalacyjnego:",
+    "Start update" : "Rozpocznij aktualizację",
+    "Continue to {productName}" : "Przejdź do {productName}",
+    "Update to {version}" : "Aktualizacja do {version}",
+    "Hide details" : "Ukryj szczegóły",
+    "Show details" : "Pokaż szczegóły",
+    "Update details" : "Szczegóły aktualizacji",
+    "Update needed" : "Wymagana aktualizacja",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Użyj aktualizatora z wiersza poleceń, ponieważ masz dużą instancję z ponad 50 kontami.",
+    "Documentation" : "Dokumentacja",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Wiem, że jeśli kontynuuję aktualizację za pomocą przeglądarki, istnieje ryzyko że operacja może nie wykonać się w określonym limicie czasu, co może doprowadzić do utraty danych, ale mam kopię zapasową i wiem jak przywrócić w przypadku niepowodzenia.",
+    "Upgrade via web on my own risk" : "Wykonaj aktualizację poprzez przeglądarkę na własne ryzyko",
+    "Search {types} …" : "Wyszukaj {types} …",
     "Choose {file}" : "Wybierz {file}",
     "Choose" : "Wybierz",
     "Copy to {target}" : "Skopiuj do {target}",
@@ -393,32 +446,20 @@ OC.L10N.register(
     "(all selected)" : "(wybrano wszystkie)",
     "({count} selected)" : "(wybrano {count})",
     "Error loading file exists template" : "Błąd podczas ładowania pliku istniejącego szablonu",
-    "Saving …" : "Zapisywanie…",
+    "Saving …" : "Zapisywanie…",
+    "Groups" : "Grupy",
+    "Group list is empty" : "Lista grup jest pusta",
+    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
     "seconds ago" : "przed chwilą",
-    "Connection to server lost" : "Utracono połączenie z serwerem",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem z wczytaniem strony, ponowne wczytanie za %n sekundę","Problem z wczytaniem strony, ponowne wczytanie za %n sekundy","Problem z wczytaniem strony, ponowne wczytanie za %n sekund","Problem z wczytaniem strony, ponowne wczytanie za %n sekund"],
     "Add to a project" : "Dodaj do projektu",
-    "Show details" : "Pokaż szczegóły",
-    "Hide details" : "Ukryj szczegóły",
     "Rename project" : "Zmień nazwę projektu",
     "Failed to rename the project" : "Nie można zmienić nazwy projektu",
     "Failed to create a project" : "Nie udało się utworzyć projektu",
     "Failed to add the item to the project" : "Nie udało się dodać elementu do projektu",
     "Connect items to a project to make them easier to find" : "Połącz elementy z projektem, aby łatwiej je znaleźć",
     "Type to search for existing projects" : "Wpisz rodzaj, aby wyszukać istniejące projekty",
-    "New in" : "Nowość w",
-    "View changelog" : "Przeglądaj listę zmian",
-    "No action available" : "Żadna akcja nie jest dostępna",
-    "Error fetching contact actions" : "Błąd podczas pobierania akcji dla kontaktu",
     "Close \"{dialogTitle}\" dialog" : "Zamknij okno \"{dialogTitle}\"",
     "Email length is at max (255)" : "Długość e-maila jest maksymalna (255)",
-    "Non-existing tag #{tag}" : "Etykieta #{tag} nie istnieje",
-    "Restricted" : "Ograniczone",
-    "Invisible" : "Niewidoczny",
-    "Delete" : "Usuń",
-    "Rename" : "Zmień nazwę",
-    "Collaborative tags" : "Etykiety wspólne",
-    "No tags found" : "Nie znaleziono etykiet",
     "Clipboard not available, please copy manually" : "Schowek nie jest dostępny, prosimy skopiować ręcznie",
     "Personal" : "Osobiste",
     "Accounts" : "Konta",
@@ -453,25 +494,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Przejdź do nawigacji aplikacji",
     "Go to %s" : "Przejdź do %s",
     "Get your own free account" : "Załóż własne bezpłatne konto",
-    "Connect to your account" : "Połącz z kontem",
-    "Please log in before granting %1$s access to your %2$s account." : "Zaloguj się przed udzieleniem dostępu %1$s do swojego konta %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeśli nie konfigurujesz nowego urządzenia lub aplikacji, to wynika z tego, że ktoś próbuje, abyś udzielił dostępu do Twoich danych. W takim przypadku nie kontynuuj, tylko skontaktuj się z administratorem systemu.",
-    "App password" : "Hasło aplikacji",
-    "Grant access" : "Udziel dostępu",
-    "Alternative log in using app password" : "Alternatywne logowanie przy użyciu hasła do aplikacji",
-    "Account access" : "Dostęp do konta",
-    "Currently logged in as %1$s (%2$s)." : "Aktualnie zalogowany jako %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Zamierzasz udzielić dostępu do swojego konta %2$s dla %1$s.",
-    "Account connected" : "Połączono z kontem",
-    "Your client should now be connected!" : "Twój klient powinien być teraz podłączony!",
-    "You can close this window." : "Możesz zamknąć to okno.",
     "Previous" : "Poprzedni",
-    "This share is password-protected" : "Udostępnienie jest zabezpieczone hasłem",
-    "The password is wrong or expired. Please try again or request a new one." : "Hasło jest nieprawidłowe lub wygasło. Spróbuj ponownie lub poproś o nowe.",
-    "Please type in your email address to request a temporary password" : "Wpisz swój adres e-mail, aby poprosić o tymczasowe hasło",
-    "Email address" : "Adres e-mail",
-    "Password sent!" : "Hasło wysłane!",
-    "You are not authorized to request a password for this share" : "Nie masz uprawnień do żądania hasła dla tego udostępnienia",
     "Two-factor authentication" : "Uwierzytelnianie dwuskładnikowe",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Dodatkowe zabezpieczenia są włączone dla Twojego konta. Wybierz drugą metodę uwierzytelniania:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nie można załadować co najmniej jednej z włączonych dwuskładnikowych metod uwierzytelnienia. Skontaktuj się z administratorem.",
@@ -486,39 +509,54 @@ OC.L10N.register(
     "Access through untrusted domain" : "Dostęp przez niezaufaną domenę",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Skontaktuj się z administratorem. Jeśli jesteś administratorem, edytuj ustawienie \"trusted_domains\" w config/config.php, tak jak w przykładzie config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Więcej informacji na temat konfiguracji można znaleźć w %1$sdokumentacji%2$s.",
-    "App update required" : "Wymagana aktualizacja aplikacji",
-    "%1$s will be updated to version %2$s" : "%1$s zostanie zaktualizowany do wersji %2$s",
-    "The following apps will be updated:" : "Następujące aplikacje zostaną zaktualizowane:",
-    "These incompatible apps will be disabled:" : "Niekompatybilne aplikacje zostaną wyłączone:",
-    "The theme %s has been disabled." : "Motyw %s został wyłączony.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Przed kontynuowaniem upewnij się, że utworzono kopię zapasową bazy danych, katalogu konfiguracyjnego i katalogu danych.",
-    "Start update" : "Rozpocznij aktualizację",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "W przypadku większych instalacji, aby uniknąć przekroczenia limitu czasu, możesz zamiast tego instalatora uruchomić następujące polecenie z katalogu instalacyjnego:",
-    "Detailed logs" : "Szczegółowe logi",
-    "Update needed" : "Wymagana aktualizacja",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Użyj aktualizatora z wiersza poleceń, ponieważ masz dużą instancję z ponad 50 kontami.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Aby uzyskać pomoc, zajrzyj do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacji</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Wiem, że jeśli kontynuuję aktualizację za pomocą przeglądarki, istnieje ryzyko że operacja może nie wykonać się w określonym limicie czasu, co może doprowadzić do utraty danych, ale mam kopię zapasową i wiem jak przywrócić w przypadku niepowodzenia.",
-    "Upgrade via web on my own risk" : "Wykonaj aktualizację poprzez przeglądarkę na własne ryzyko",
     "Maintenance mode" : "Tryb konserwacji",
     "This %s instance is currently in maintenance mode, which may take a while." : "Ta instancja %s jest obecnie w trybie konserwacji, co może chwilę potrwać.",
     "This page will refresh itself when the instance is available again." : "Strona odświeży się, gdy instancja będzie ponownie dostępna.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Skontaktuj się z administratorem systemu, jeśli ten komunikat będzie się powtarzał lub pojawił się nieoczekiwanie.",
     "Error occurred while checking server setup" : "Wystąpił błąd podczas sprawdzania konfiguracji serwera",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Czat, rozmowy wideo, udostępnianie ekranu, spotkania online i konferencje internetowe - w przeglądarce i aplikacjach mobilnych.",
-    "You have not added any info yet" : "Nie dodałeś jeszcze żadnych informacji",
-    "{user} has not added any info yet" : "{user} nie dodał jeszcze żadnych informacji",
-    "Error opening the user status modal, try hard refreshing the page" : "Błąd podczas otwierania modalnego statusu użytkownika, spróbuj bardziej odświeżyć stronę",
-    "Edit Profile" : "Edytuj profil",
-    "The headline and about sections will show up here" : "Tutaj pojawi się nagłówek i informacje o sekcjach",
+    "unknown text" : "nieznany tekst",
+    "Hello world!" : "Witaj świecie!",
+    "sunny" : "słoneczna",
+    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
+    "Hello {name}" : "Witaj {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To są twoje wyniki wyszukiwania<script>alert(1)</script></strong>",
+    "new" : "nowy",
+    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n pliki","pobrano %n plików","pobrano %n plików"],
+    "An error occurred." : "Wystąpił błąd.",
+    "Please reload the page." : "Przeładuj stronę.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizacja nie powiodła się. Aby uzyskać więcej informacji, <a href=\"{url}\">zapoznaj się z naszym postem na forum</a> dotyczącym tego problemu.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizacja nie powiodła się. Zgłoś ten problem do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">społeczności Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundę.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundy.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund."],
+    "Direct link copied to clipboard" : "Bezpośredni odnośnik skopiowany do schowka",
+    "Searching …" : "Wyszukiwanie…",
+    "Logging in …" : "Logowanie…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Wykryliśmy wiele nieudanych prób logowania z Twojego adresu IP. Dlatego następne logowanie będzie możliwe dopiero za 30 sekund.",
+    "Loading apps …" : "Wczytywanie aplikacji…",
+    "Installing apps …" : "Instalowanie aplikacji…",
+    "Loading your contacts …" : "Wczytywanie kontaktów…",
+    "Looking for {term} …" : "Szukam {term}…",
+    "Search contacts …" : "Wyszukiwanie kontaktów…",
+    "Loading more results …" : "Wczytuję więcej wyników…",
+    "Search {types} …" : "Wyszukaj {types}…",
+    "Saving …" : "Zapisywanie…",
+    "Connection to server lost" : "Utracono połączenie z serwerem",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem z wczytaniem strony, ponowne wczytanie za %n sekundę","Problem z wczytaniem strony, ponowne wczytanie za %n sekundy","Problem z wczytaniem strony, ponowne wczytanie za %n sekund","Problem z wczytaniem strony, ponowne wczytanie za %n sekund"],
+    "New in" : "Nowość w",
+    "View changelog" : "Przeglądaj listę zmian",
     "Very weak password" : "Bardzo słabe hasło",
     "Weak password" : "Słabe hasło",
     "So-so password" : "Mało skomplikowane hasło",
     "Good password" : "Dobre hasło",
     "Strong password" : "Silne hasło",
-    "Profile not found" : "Nie znaleziono profilu",
-    "The profile does not exist." : "Profil nie istnieje.",
+    "No action available" : "Żadna akcja nie jest dostępna",
+    "Error fetching contact actions" : "Błąd podczas pobierania akcji dla kontaktu",
+    "Non-existing tag #{tag}" : "Etykieta #{tag} nie istnieje",
+    "Restricted" : "Ograniczone",
+    "Delete" : "Usuń",
+    "Rename" : "Zmień nazwę",
+    "Collaborative tags" : "Etykiety wspólne",
+    "No tags found" : "Nie znaleziono etykiet",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacje na temat prawidłowej konfiguracji serwera można znaleźć w <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentacji</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Utwórz konto administratora</strong>",
@@ -529,6 +567,14 @@ OC.L10N.register(
     "Configure the database" : "Skonfiguruj bazę danych",
     "Only %s is available." : "Dostępne jest tylko %s.",
     "Database account" : "Konto bazy danych",
-    "Direct link copied to clipboard" : "Bezpośredni odnośnik skopiowany do schowka"
+    "Installing …" : "Instalowanie…",
+    "Please log in before granting %1$s access to your %2$s account." : "Zaloguj się przed udzieleniem dostępu %1$s do swojego konta %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Aktualnie zalogowany jako %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Zamierzasz udzielić dostępu do swojego konta %2$s dla %1$s.",
+    "%1$s will be updated to version %2$s" : "%1$s zostanie zaktualizowany do wersji %2$s",
+    "The following apps will be updated:" : "Następujące aplikacje zostaną zaktualizowane:",
+    "The theme %s has been disabled." : "Motyw %s został wyłączony.",
+    "Detailed logs" : "Szczegółowe logi",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Aby uzyskać pomoc, zajrzyj do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacji</a>."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
