@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "檔案類型不詳",
     "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
     "Invalid image" : "圖像無效",
-    "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
-    "No crop data provided" : "未提供剪裁設定",
-    "No valid crop data provided" : "未提供有效的剪裁設定",
-    "Crop is not square" : "剪裁設定不是正方形",
     "State token does not match" : "狀態權杖不相符",
     "Invalid app password" : "無效的應用程式密碼",
     "Could not complete login" : "無法完成登錄",
     "State token missing" : "找不到狀態權杖",
     "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
+    "Please use original client" : "請使用原先的客戶端",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "這個社群版的 Nextcloud 是不受支援的，且推送通知功能有限。",
     "Login" : "登入",
     "Unsupported email length (>255)" : "不受支援的電郵地址長度（>255）",
@@ -43,14 +40,24 @@ OC.L10N.register(
     "Task not found" : "找不到任務",
     "Internal error" : "內部錯誤",
     "Not found" : "找不到",
+    "Node is locked" : "節點已上鎖",
     "Bad request" : "請求無效",
+    "Input text is too long" : "輸入文字太長",
     "Requested task type does not exist" : "請求的任務類型不存在",
     "Necessary language model provider is not available" : "沒有可用的語言模型提供者",
+    "Cannot generate more than 12 images" : "無法產生超過 12 張圖像",
+    "Cannot generate less than 1 image" : "至少需要產生 1 張圖片",
     "No text to image provider is available" : "沒有可用的文字轉圖像提供者",
     "Image not found" : "找不到圖像",
     "No translation provider available" : "沒有可用翻譯提供者",
     "Could not detect language" : "無法檢測語言",
     "Unable to translate" : "無法翻譯",
+    "No valid filters provided" : "未提供有效的篩選條件",
+    "[%d / %d]: %s" : "[%d / %d]：%s",
+    "Repair step:" : "修復步驟：",
+    "Repair info:" : "修復資訊：",
+    "Repair warning:" : "修復警告：",
+    "Repair error:" : "修復錯誤：",
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加帳戶限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
     "Learn more ↗" : "了解更多",
     "Preparing update" : "正在準備更新",
-    "[%d / %d]: %s" : "[%d / %d]：%s",
-    "Repair step:" : "修復步驟：",
-    "Repair info:" : "修復資訊：",
-    "Repair warning:" : "修復警告：",
-    "Repair error:" : "修復錯誤：",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "由於更新功能已在 config.php 中設定停用，請使用命令列（command line）更新系統。",
     "Turned on maintenance mode" : "已啟用維護模式",
     "Turned off maintenance mode" : "停用維護模式",
@@ -79,37 +81,144 @@ OC.L10N.register(
     "%s (incompatible)" : "%s （不相容）",
     "The following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
     "Already up to date" : "此版本為最新版本",
-    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkend}。",
-    "unknown text" : "文字不詳",
-    "Hello world!" : "哈囉，世界！",
-    "sunny" : "晴朗的",
-    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今日天氣 {weather}",
-    "Hello {name}" : "哈囉 {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告（1）</script></strong>",
-    "new" : "新",
-    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
-    "Update to {version}" : "更新到 {version}",
-    "An error occurred." : "發生錯誤。",
-    "Please reload the page." : "請重新整理頁面。",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">請查看我們關於此問題的論壇帖子</a>來瞭解更多。",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
-    "Continue to {productName}" : "前往 {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
+    "Windows Command Script" : "Windows 命令腳本",
+    "Electronic book document" : "電子書文件",
+    "TrueType Font Collection" : "TrueType 字體集",
+    "Web Open Font Format" : "網絡開放字體格式",
+    "GPX geographic data" : "GPX 地理數據",
+    "Gzip archive" : "Gzip 封存檔",
+    "Adobe Illustrator document" : "Adobe Illustrator 文件",
+    "Java source code" : "Java 源碼",
+    "JavaScript source code" : "JavaScript 源碼",
+    "JSON document" : "JSON 文件",
+    "Microsoft Access database" : "Microsoft Access 數據庫",
+    "Microsoft OneNote document" : "Microsoft OneNote 文件",
+    "Microsoft Word document" : "Microsoft Word 文件",
+    "Unknown" : "不詳",
+    "PDF document" : "PDF 文件",
+    "PostScript document" : "PostScript 文件",
+    "RSS summary" : "RSS 摘要",
+    "Android package" : "Android 軟體包",
+    "KML geographic data" : "KML 地理數據",
+    "KML geographic compressed data" : "KML 壓縮地理數據",
+    "Lotus Word Pro document" : "Lotus Word Pro 文件",
+    "Excel spreadsheet" : "Excel 試算表",
+    "Excel add-in" : "Excel 附加元件",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 二進制試算表",
+    "Excel spreadsheet template" : "Excel 試算表模板",
+    "Outlook Message" : "Outlook 郵件",
+    "PowerPoint presentation" : "PowerPoint 演示文稿",
+    "PowerPoint add-in" : "PowerPoint 附加元件",
+    "PowerPoint presentation template" : "PowerPoint 演示文稿模板",
+    "Word document" : "Word 文件",
+    "ODF formula" : "ODF 公式",
+    "ODG drawing" : "ODG 繪圖",
+    "ODG drawing (Flat XML)" : "ODG 繪圖（扁平 XML）",
+    "ODG template" : "ODG 模板",
+    "ODP presentation" : "ODP 演示文稿",
+    "ODP presentation (Flat XML)" : "ODP 演示文稿（扁平 XML）",
+    "ODP template" : "ODP 模板",
+    "ODS spreadsheet" : "ODS 試算表",
+    "ODS spreadsheet (Flat XML)" : "ODS 試算表（扁平 XML）",
+    "ODS template" : "ODS 模板",
+    "ODT document" : "ODT 文件",
+    "ODT document (Flat XML)" : "ODT 文件（扁平 XML）",
+    "ODT template" : "ODT 模板",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 演示文稿",
+    "PowerPoint 2007 show" : "PowerPoint 2007 放映",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 演示文稿模板",
+    "Excel 2007 spreadsheet" : "Excel 2007 試算表",
+    "Excel 2007 spreadsheet template" : "Excel 2007 試算表模板",
+    "Word 2007 document" : "Word 2007 文件",
+    "Word 2007 document template" : "Word 2007 文件模板",
+    "Microsoft Visio document" : "Microsoft Visio 文件",
+    "WordPerfect document" : "WordPerfect 文件",
+    "7-zip archive" : "7-zip 壓縮檔",
+    "Blender scene" : "Blender 場景",
+    "Bzip2 archive" : "Bzip2 壓縮檔",
+    "Debian package" : "Debian 包",
+    "FictionBook document" : "FictionBook 文件",
+    "Unknown font" : "未知字體",
+    "Krita document" : "Krita 文件",
+    "Mobipocket e-book" : "Mobipocket 電子書",
+    "Windows Installer package" : "Windows 安裝包",
+    "Perl script" : "Perl 腳本",
+    "PHP script" : "PHP 腳本",
+    "Tar archive" : "Tar 壓縮檔",
+    "XML document" : "XML 文件",
+    "YAML document" : "YAML 文件",
+    "Zip archive" : "Zip 封存檔",
+    "Zstandard archive" : "Zstandard 封存檔",
+    "AAC audio" : "AAC 音頻",
+    "FLAC audio" : "FLAC 音頻",
+    "MPEG-4 audio" : "MPEG-4 音頻",
+    "MP3 audio" : "MP3 音頻",
+    "Ogg audio" : "Ogg 音頻",
+    "RIFF/WAVe standard Audio" : "RIFF/WAV 標準音頻",
+    "WebM audio" : "WebM 音頻",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast 播放列表",
+    "Windows BMP image" : "Windows BMP 圖像",
+    "Better Portable Graphics image" : "Better Portable Graphics 圖像",
+    "EMF image" : "EMF 圖像",
+    "GIF image" : "GIF 圖像",
+    "HEIC image" : "HEIC 圖像",
+    "HEIF image" : "HEIF 圖像",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 圖像",
+    "JPEG image" : "JPEG 圖像",
+    "PNG image" : "PNG 圖像",
+    "SVG image" : "SVG 圖像",
+    "Truevision Targa image" : "Truevision Targa 圖像",
+    "TIFF image" : "TIFF 圖像",
+    "WebP image" : "WebP 圖像",
+    "Digital raw image" : "數碼原始圖像",
+    "Windows Icon" : "Windows 圖標",
+    "Email message" : "電子郵件消息",
+    "VCS/ICS calendar" : "VCS/ICS 日曆",
+    "CSS stylesheet" : "CSS 樣式表",
+    "CSV document" : "CSV 文件",
+    "HTML document" : "HTML 文件",
+    "Markdown document" : "Markdown 文件",
+    "Org-mode file" : "Org-mode 文件",
+    "Plain text document" : "純文本文件",
+    "Rich Text document" : "富文本文件",
+    "Electronic business card" : "電子名片",
+    "C++ source code" : "C++ 源碼",
+    "LDIF address book" : "LDIF 通訊錄",
+    "NFO document" : "NFO 文件",
+    "PHP source" : "PHP 源碼",
+    "Python script" : "Python 腳本",
+    "ReStructuredText document" : "ReStructuredText 文件",
+    "3GPP multimedia file" : "3GPP 多媒體文件",
+    "MPEG video" : "MPEG 視頻",
+    "DV video" : "DV 視頻",
+    "MPEG-2 transport stream" : "MPEG-2 傳輸流",
+    "MPEG-4 video" : "MPEG-4 視頻",
+    "Ogg video" : "Ogg 視頻",
+    "QuickTime video" : "QuickTime 視頻",
+    "WebM video" : "WebM 視頻",
+    "Flash video" : "Flash 視頻",
+    "Matroska video" : "Matroska 視頻",
+    "Windows Media video" : "Windows Media 視頻",
+    "AVI video" : "AVI 視頻",
+    "Done" : "完成",
+    "Scan QR code to log in" : "掃描 QR code 以登入",
+    "Use {productName} mobile client you want to connect to scan the code" : "使用您要連線的 {productName} 行動裝置客戶端掃描此條碼",
+    "Code will expire {timeCountdown} or after use" : "條碼會在 {timeCountdown} 後或使用後失效",
     "Applications menu" : "應用程式選項單",
     "Apps" : "應用程式",
     "More apps" : "更多應用程式",
     "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
     "No" : "否",
     "Yes" : "是",
+    "App password" : "應用程式密碼",
+    "Grant access" : "允許存取",
     "The remote URL must include the user." : "遠端 URL 必須包含用戶。",
     "Invalid remote URL." : "無效的遠端 URL。",
     "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
     "Federated user" : "聯盟用戶",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "創建分享",
-    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Direct link copied" : "已複製直接連結",
     "Please copy the link manually:" : "請手動複製連結：",
     "Custom date range" : "自訂日期範圍",
     "Pick start date" : "挑選開始日期",
@@ -118,14 +227,16 @@ OC.L10N.register(
     "Search in current app" : "在目前的應用程式中搜尋",
     "Clear search" : "清除搜尋",
     "Search everywhere" : "到處搜尋",
-    "Searching …" : "正在搜尋……",
+    "Searching …" : "搜尋中 …",
     "Start typing to search" : "輸入文字以檢索",
+    "Minimum search length is {minSearchLength} characters" : "最小搜尋長度為 {minSearchLength} 個字元",
     "No matching results" : "無相符結果",
     "Today" : "今日",
     "Last 7 days" : "過去7日",
     "Last 30 days" : "過去30日",
     "This year" : "今年",
     "Last year" : "去年",
+    "Between {startDate} and {endDate}" : "{startDate} 到 {endDate} 之間",
     "Unified search" : "統一搜尋",
     "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
     "Places" : "地點",
@@ -133,30 +244,33 @@ OC.L10N.register(
     "Search people" : "搜尋人仕",
     "People" : "人物",
     "Filter in current view" : "目前檢視裡的篩選條件",
+    "Search connected services" : "搜尋已連結的服務",
     "Results" : "結果",
     "Load more results" : "載入更多結果",
     "Search in" : "搜尋",
+    "Partial matches" : "部份符合",
     "Log in" : "登入",
-    "Logging in …" : "正在登入 …",
+    "Logging in …" : "正在登入 …",
     "Log in to {productName}" : "登入至 {productName}",
     "Wrong login or password." : "登入名稱或密碼錯誤。",
     "This account is disabled" : "此帳戶已停用",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時30秒。請耐心等待一段時間後再試。",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "登入嘗試錯誤次數過多，請於 30 秒後再試。",
     "Account name or email" : "帳戶名稱或電郵地址",
     "Account name" : "帳戶名稱",
     "Server side authentication failed!" : "伺服器端認證失敗！",
     "Please contact your administrator." : "請聯絡系統管理員。",
-    "Temporary error" : "暫時出現錯誤",
-    "Please try again." : "請再試一次。",
+    "Session error" : "工作階段錯誤",
+    "It appears your session token has expired, please refresh the page and try again." : "您的工作階段權杖似乎已過期，請重新整理頁面並重試。",
     "An internal error occurred." : "發生內部錯誤。",
     "Please try again or contact your administrator." : "請重試或聯絡系統管理員。",
     "Password" : "密碼",
+    "Remember me" : "記住我",
     "Log in with a device" : "使用免密碼裝置登入",
     "Login or email" : "帳戶或電子郵件",
     "Your account is not setup for passwordless login." : "你的賬號尚未設定免密碼登入。",
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身分驗證僅支援經加密的連線。",
-    "Browser not supported" : "不支持該瀏覽器",
+    "Browser not supported" : "不支援該瀏覽器",
     "Passwordless authentication is not supported in your browser." : "你使用的瀏覽器不支援無密碼身分驗證。",
     "Reset password" : "重設密碼",
     "Back to login" : "回到登入畫面",
@@ -174,23 +288,34 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基於 Collabora Online 構建的協作文件、試算表和演講文稿。",
     "Distraction free note taking app." : "無干擾的筆記應用程式。",
     "Recommended apps" : "推薦的應用程式",
-    "Loading apps …" : "正在載入應用程式 …",
+    "Loading apps …" : "正在載入應用程式 ……",
     "Could not fetch list of apps from the App Store." : "無法從 App Store 擷取應用程式清單。",
     "App download or installation failed" : "應用程式下載或是安裝失敗",
     "Cannot install this app because it is not compatible" : "由於不兼容，無法安裝此應用程式",
     "Cannot install this app" : "無法安裝此應用程式",
     "Skip" : "略過",
-    "Installing apps …" : "正在安裝應用程式…",
+    "Installing apps …" : "正在安裝應用程式 ……",
     "Install recommended apps" : "安裝推薦的應用程式",
+    "Online" : "在線",
+    "Away" : "離開",
+    "Busy" : "忙碌",
+    "Do not disturb" : "請勿打擾",
+    "Mute all notifications" : "所有通知靜音",
+    "Invisible" : "隱藏",
+    "Appear offline" : "顯示為離線",
     "Avatar of {displayName}" : "{displayName} 的虛擬化身",
     "Settings menu" : "設定選項單",
-    "Loading your contacts …" : "正在載入聯絡人…",
-    "Looking for {term} …" : "正在搜尋 {term} …",
+    "Loading your contacts …" : "正在載入您的聯絡人 ……",
+    "Looking for {term} …" : "正在尋找 {term} ……",
     "Search contacts" : "搜尋聯絡人",
+    "Filter by team" : "以團隊過濾",
+    "All teams" : "所有團隊",
+    "Search contacts in team {team}" : "在 {team} 團隊中搜尋聯絡人",
+    "Search contacts …" : "搜尋聯絡人 ……",
     "Reset search" : "重設搜尋",
-    "Search contacts …" : "搜尋聯絡人…",
     "Could not load your contacts" : "無法載入您的聯絡人",
     "No contacts found" : "找不到聯絡人",
+    "Contacts list" : "聯絡人清單",
     "Show all contacts" : "顯示所有聯絡人",
     "Install the Contacts app" : "安裝「通訊錄」應用程式",
     "Search" : "搜尋",
@@ -200,13 +325,39 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
     "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您開始輸入，搜尋就會開始，您可以使用方向鍵到達結果",
     "Search for {name} only" : "只搜尋 {name}",
-    "Loading more results …" : "正在載入更多結果...",
+    "Loading more results …" : "正在載入更多結果 ……",
     "Forgot password?" : "忘記密碼？",
     "Back to login form" : "回到登入表格",
     "Back" : "返回",
     "Login form is disabled." : "登入表格已停用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
+    "Connect to your account" : "連結您的賬號",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "請先登入，再授權「{client}」存取您 {instanceName} 帳號。",
+    "Security warning" : "安全性警示",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若你並未嘗試在新的裝置登入你的帳戶，有什麼人證在嘗試登入你的帳戶並存取你的個人資料。大多數情況你並不用作任何應對，但也可通知你的系統管理員。",
+    "Log in using password" : "使用密碼登入",
+    "Alternative log in using app password" : "使用應用程式密碼來登入",
+    "Account connected" : "帳戶已連結",
+    "Your client should now be connected!" : "客戶端應該已完成連線",
+    "You can close this window." : "可以關閉此視窗",
+    "Account access" : "帳戶存取",
+    "Currently logged in as {userDisplayName} ({userId})." : "目前登入為 {userDisplayName} ({userId})。",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "您將要授權「{client}」存取您的 {instanceName} 帳號。",
     "More actions" : "更多操作",
+    "User menu" : "用戶選項單",
+    "Your guest name: {user}" : "您的訪客名稱：{user}",
+    "You are currently not identified." : "目前無法辨識您的身分。",
+    "Set public name" : "設定公開名稱",
+    "Change public name" : "變更公開名稱",
+    "This share is password-protected" : "此分享受密碼保護",
+    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。 請重試或重新申請。",
+    "Submit" : "遞交",
+    "Please type in your email address to request a temporary password" : "請輸入您的電郵地址以申請臨時密碼",
+    "Password sent!" : "密碼已傳送！",
+    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
+    "Email address" : "電郵地址",
+    "Request password" : "索取密碼",
+    "Forgot password" : "忘記密碼",
     "Password is too weak" : "密碼強度非常弱",
     "Password is weak" : "密碼強度弱",
     "Password is average" : "密碼強度一般",
@@ -218,13 +369,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "有關如何正確配置伺服器的資訊，請參閱{linkStart}說明書{linkEnd}",
     "Autoconfig file detected" : "偵測到自動配置檔案",
     "The setup form below is pre-filled with the values from the config file." : "下面的設置表格已根據配置檔案的值自動填充。",
-    "Security warning" : "安全性警示",
     "Create administration account" : "建立管理員帳戶",
     "Administration account name" : "管理員帳戶名稱",
     "Administration account password" : "管理員帳戶密碼",
     "Storage & database" : "儲存空間和數據庫",
     "Data folder" : "資料儲存位置",
     "Database configuration" : "數據庫配置",
+    "Database type" : "數據庫類型",
     "Only {firstAndOnlyDatabase} is available." : "僅 {firstAndOnlyDatabase} 可用。",
     "Install and activate additional PHP modules to choose other database types." : "安裝並啟動相關 PHP 模組來使用其他種數據庫",
     "For more details check out the documentation." : "要取得更多細節資訊，請參閱說明書。",
@@ -232,6 +383,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "您選擇了 SQLite 作為數據庫",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他數據庫後端。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
+    "Database connection" : "數據庫連接",
     "Database user" : "數據庫用戶",
     "Database password" : "數據庫密碼",
     "Database name" : "數據庫名稱",
@@ -239,7 +391,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
     "Database host" : "數據庫主機",
     "localhost" : "localhost",
-    "Installing …" : "正在安裝 …",
+    "Installing …" : "正在安裝 ……",
     "Install" : "安裝",
     "Need help?" : "需要協助嗎？",
     "See the documentation" : "閱讀說明文件",
@@ -248,7 +400,33 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
     "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
-    "Search {types} …" : "搜尋 {types} 中 …",
+    "The update completed with warnings. Please check the details for more information." : "更新已完成，但出現警告。請查看詳細資料以了解更多資訊。",
+    "The update completed successfully." : "更新已成功完成。",
+    "Preparing update…" : "正在準備更新…",
+    "You will be redirected to {productName} in {count} seconds." : "系統將於 {count} 秒後重新導向至 {productName}。",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
+    "App update required" : "需要更新應用程式",
+    "{productName} will be updated to version {version}" : "{productName} 將更新至版本 {version}",
+    "The theme {oldTheme} has been disabled." : "主題 {oldTheme} 已被停用。",
+    "These incompatible apps will be disabled:" : "以下不兼容的應用程式將被停用：",
+    "Incompatible apps" : "不兼容的應用程式",
+    "These apps will be updated:" : "將會更新這些應用程式",
+    "Apps to update" : "需要更新的應用程式",
+    "{app} from {oldVersion} to {version}" : "{app}：由 {oldVersion} 更新至 {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄下運行以下指令：",
+    "Start update" : "開始升級",
+    "Continue to {productName}" : "前往 {productName}",
+    "Update to {version}" : "更新到 {version}",
+    "Hide details" : "隱藏細節",
+    "Show details" : "顯示細節",
+    "Update details" : "更新詳情",
+    "Update needed" : "需要更新",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過50名帳戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
+    "Documentation" : "說明書",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
+    "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
+    "Search {types} …" : "搜尋 {types} ……",
     "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
     "Copy to {target}" : "複製到 {target}",
@@ -268,41 +446,30 @@ OC.L10N.register(
     "(all selected)" : "（已全選）",
     "({count} selected)" : "（已選擇 {count} 項）",
     "Error loading file exists template" : "載入已存在的模板時發生錯誤",
-    "Saving …" : "儲存中 ...",
+    "Saving …" : "儲存中 ...",
+    "Groups" : "群組",
+    "Group list is empty" : "群組列表為空",
+    "Unable to retrieve the group list" : "無法擷取群組列表",
     "seconds ago" : "幾秒前",
-    "Connection to server lost" : "伺服器連線中斷",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
     "Add to a project" : "加到專案",
-    "Show details" : "顯示細節",
-    "Hide details" : "隱藏細節",
     "Rename project" : "重新命名專案",
     "Failed to rename the project" : "重新命名專案失敗",
     "Failed to create a project" : "建立專案失敗",
     "Failed to add the item to the project" : "新增項目至專案時失敗",
     "Connect items to a project to make them easier to find" : "將項目連結到專案以便尋找",
     "Type to search for existing projects" : "搜尋現有專案",
-    "New in" : "新加入",
-    "View changelog" : "檢視版本更新紀錄",
-    "No action available" : "沒有可用的操作",
-    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Close \"{dialogTitle}\" dialog" : "關閉 \"{dialogTitle}\" 對話",
     "Email length is at max (255)" : "電子郵件已達到最大長度（255 個字元）",
-    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
-    "Restricted" : "受限",
-    "Invisible" : "隱藏",
-    "Delete" : "刪除",
-    "Rename" : "重新命名",
-    "Collaborative tags" : "協作標籤",
-    "No tags found" : "查無標籤",
     "Clipboard not available, please copy manually" : "剪貼板不可用，請人手複製",
     "Personal" : "個人",
     "Accounts" : "帳戶",
     "Admin" : "管理",
     "Help" : "說明",
     "Access forbidden" : "存取被拒",
+    "You are not allowed to access this page." : "您無法存取此頁面。",
+    "Back to %s" : "回到 %s",
     "Page not found" : "沒有找到頁面",
     "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無法查看它。",
-    "Back to %s" : "回到 %s",
     "Too many requests" : "太多要求",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
     "Error" : "錯誤",
@@ -327,25 +494,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "跳到應用程式導覽",
     "Go to %s" : "前往 %s",
     "Get your own free account" : "取得免費賬號",
-    "Connect to your account" : "連結您的賬號",
-    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 賬號",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若你並未嘗試在新的裝置登入你的帳戶，有什麼人證在嘗試登入你的帳戶並存取你的個人資料。大多數情況你並不用作任何應對，但也可通知你的系統管理員。",
-    "App password" : "應用程式密碼",
-    "Grant access" : "允許存取",
-    "Alternative log in using app password" : "使用應用程式密碼來登入",
-    "Account access" : "帳戶存取",
-    "Currently logged in as %1$s (%2$s)." : "目前以 %1$s (%2$s) 身份登入。",
-    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳戶",
-    "Account connected" : "帳戶已連結",
-    "Your client should now be connected!" : "客戶端應該已完成連線",
-    "You can close this window." : "可以關閉此視窗",
     "Previous" : "上一個",
-    "This share is password-protected" : "此分享受密碼保護",
-    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。 請重試或重新申請。",
-    "Please type in your email address to request a temporary password" : "請輸入您的電郵地址以申請臨時密碼",
-    "Email address" : "電郵地址",
-    "Password sent!" : "密碼已傳送！",
-    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
     "Two-factor authentication" : "雙重認證",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的賬號已啟用進階安全機制，請選擇一個雙重認證方法：",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何已啟用的雙重認證方法，請聯絡管理員。",
@@ -360,41 +509,54 @@ OC.L10N.register(
     "Access through untrusted domain" : "經由不可信任的域名存取。",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "請聯絡您的管理員。如果您就是管理員，請模仿 config.sample.php 範例編輯 config/config.php 的「trusted_domains」設定。",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "更多關於如何設定的資訊，請見%1$s文件%2$s。",
-    "App update required" : "需要更新應用程式",
-    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
-    "The following apps will be updated:" : "將更新以下的 APP：",
-    "These incompatible apps will be disabled:" : "以下不兼容的應用程式將被停用：",
-    "The theme %s has been disabled." : "主題 %s 已經被停用。",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
-    "Start update" : "開始升級",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄下運行以下指令：",
-    "Detailed logs" : "詳細記錄檔",
-    "Update needed" : "需要更新",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過50名帳戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
-    "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
     "Maintenance mode" : "維護模式",
     "This %s instance is currently in maintenance mode, which may take a while." : "此 %s 實例目前處於維護模式，可能需要一段時間才能完成。",
     "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "Currently open" : "目前開啟",
-    "Login with username or email" : "以用戶名稱或電郵地址登入",
-    "Login with username" : "以用戶名稱登入",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
-    "You have not added any info yet" : "您尚未新增任何資訊",
-    "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
-    "Error opening the user status modal, try hard refreshing the page" : "打開用戶狀態模式時出錯，請嘗試刷新頁面",
-    "Edit Profile" : "編輯個人設定",
-    "The headline and about sections will show up here" : "標題與關於部份將在此顯示",
-    "Error loading message template: {error}" : "載入訊息模板時出錯： {error}",
+    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkend}。",
+    "unknown text" : "文字不詳",
+    "Hello world!" : "哈囉，世界！",
+    "sunny" : "晴朗的",
+    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今日天氣 {weather}",
+    "Hello {name}" : "哈囉 {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告（1）</script></strong>",
+    "new" : "新",
+    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
+    "An error occurred." : "發生錯誤。",
+    "Please reload the page." : "請重新整理頁面。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">請查看我們關於此問題的論壇帖子</a>來瞭解更多。",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
+    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Searching …" : "正在搜尋……",
+    "Logging in …" : "正在登入 …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時30秒。請耐心等待一段時間後再試。",
+    "Loading apps …" : "正在載入應用程式 …",
+    "Installing apps …" : "正在安裝應用程式…",
+    "Loading your contacts …" : "正在載入聯絡人…",
+    "Looking for {term} …" : "正在搜尋 {term} …",
+    "Search contacts …" : "搜尋聯絡人…",
+    "Loading more results …" : "正在載入更多結果...",
+    "Search {types} …" : "搜尋 {types} 中 …",
+    "Saving …" : "儲存中 ...",
+    "Connection to server lost" : "伺服器連線中斷",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
+    "New in" : "新加入",
+    "View changelog" : "檢視版本更新紀錄",
     "Very weak password" : "密碼安全性極弱",
     "Weak password" : "密碼安全性弱",
     "So-so password" : "密碼安全性普通",
     "Good password" : "密碼安全性佳",
     "Strong password" : "密碼強度極佳",
-    "Profile not found" : "找不到個人資料",
-    "The profile does not exist." : "個人資料不存在",
+    "No action available" : "沒有可用的操作",
+    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
+    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
+    "Restricted" : "受限",
+    "Delete" : "刪除",
+    "Rename" : "重新命名",
+    "Collaborative tags" : "協作標籤",
+    "No tags found" : "查無標籤",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄可能可以從互聯網存取，因為 .htaccess 不起作用。",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "有關如何正確配置伺服器的信息，請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明書</a>。",
     "<strong>Create an admin account</strong>" : "<strong>創建管理員帳戶</strong>",
@@ -404,6 +566,15 @@ OC.L10N.register(
     "Toggle password visibility" : "切換密碼可見性",
     "Configure the database" : "設定數據庫",
     "Only %s is available." : "僅 %s 可使用。",
-    "Database account" : "數據庫帳戶"
+    "Database account" : "數據庫帳戶",
+    "Installing …" : "正在安裝 …",
+    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 賬號",
+    "Currently logged in as %1$s (%2$s)." : "目前以 %1$s (%2$s) 身份登入。",
+    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳戶",
+    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
+    "The following apps will be updated:" : "將更新以下的 APP：",
+    "The theme %s has been disabled." : "主題 %s 已經被停用。",
+    "Detailed logs" : "詳細記錄檔",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>"
 },
 "nplurals=1; plural=0;");
