@@ -160,7 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Nie można nawiązać połączenia z bazą danych Oracle",
     "Oracle Login and/or password not valid" : "Nieprawidłowy login i/lub hasło do Oracle",
     "PostgreSQL Login and/or password not valid" : "Nieprawidłowy login i/lub hasło do PostgreSQL",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X nie jest obsługiwany i %s może nie działać poprawnie na tej platformie. Używasz na własne ryzyko!",
+    "macOS is not supported and %s will not work properly on this platform." : "Mac OS X nie jest obsługiwany i %s może nie działać poprawnie na tej platformie.",
     "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepszy efekt, rozważ użycie serwera GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Wydaje się, że ta instancja %s używa PHP dla 32-bitowego środowiska, ponieważ open_basedir został tak skonfigurowany w php.ini. Doprowadzi to do problemów z plikami powyżej 4 GB i jest bardzo niezalecane.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Usuń ustawienie open_basedir w php.ini lub przełącz na PHP 64-bitowe.",
@@ -225,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Nie można znaleźć kategorii \"%s\"",
     "Input text" : "Wprowadź tekst",
     "The input text" : "Wprowadzony tekst",
+    "Cannot generate more than 12 images" : "Nie można wygenerować więcej niż 12 obrazów",
+    "Cannot generate less than 1 image" : "Nie można wygenerować mniej niż 1 obraz",
     "Sunday" : "Niedziela",
     "Monday" : "Poniedziałek",
     "Tuesday" : "Wtorek",
@@ -379,6 +381,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Tekst, dla którego ma zostać wygenerowana emoji",
     "Generated emoji" : "Wygenerowane emoji",
     "The generated emoji based on the input text" : "Wygenerowana emoji na podstawie wprowadzonego tekstu",
+    "Optical character recognition" : "Optyczne rozpoznawanie znaków",
+    "Extract text from files like images or PDFs" : "Wyodrębnij tekst z plików takich jak obrazy lub pliki PDF",
+    "Input files" : "Pliki wejściowe",
+    "The files to extract text from" : "Pliki, z których ma zostać wyodrębniony tekst",
+    "Output texts" : "Teksty wyjściowe",
+    "The texts that were extracted from the files" : "Teksty wyodrębnione z plików",
     "Generate image" : "Generuj obraz",
     "Generate an image from a text prompt" : "Wygeneruj obraz z opisu tekstowego",
     "Prompt" : "Polecenie",
@@ -469,6 +477,7 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Podsumowuje tekst, zmniejszając jego długość bez utraty kluczowych informacji.",
     "Extracts topics from a text and outputs them separated by commas." : "Wyodrębnia tematy z tekstu i wyświetla je oddzielone przecinkami.",
     "Organisation" : "Organizacja",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X nie jest obsługiwany i %s może nie działać poprawnie na tej platformie. Używasz na własne ryzyko!",
     "Login is too long" : "Login jest zbyt długi",
     "Cannot write into \"apps\" directory." : "Nie można zapisać do katalogu \"apps\".",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Zwykle można to naprawić, przyznając serwerowi WWW dostęp do zapisu do katalogu aplikacji lub wyłączając Nextcloud App Store w pliku konfiguracyjnym.",
