@@ -2,7 +2,7 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Не можу писати у каталог \"config\"!",
-    "This can usually be fixed by giving the web server write access to the config directory." : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Зазвичай це можна виправити шляхом надання вебсерверу доступу на запису до каталогу конфігурації.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Але якщо ви віддаєте перевагу файлу config.php лише для читання, встановіть для параметра \"config_is_read_only\" значення true.",
     "See %s" : "Переглянути %s",
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Застосунок %1$s відсутній або має несумісну з цим сервером версію. Будь ласка, перевірте каталог додатків.",
@@ -53,7 +53,7 @@ OC.L10N.register(
     "A remote wipe was started on device %s" : "На пристрої %s розпочато віддалене стирання",
     "Remote wipe finished" : "Віддалене стирання завершено",
     "The remote wipe on %s has finished" : "Дистанційне стирання на %s завершено",
-    "Authentication" : "Авторизація",
+    "Authentication" : "Автентифікація",
     "Unknown filetype" : "Невідомий тип файлу",
     "Invalid image" : "Недійсне зображення",
     "Avatar image is not square" : "Зображення аватара не квадратне",
@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Призначення відсутнє",
     "Destination is not creatable" : "Неможливо створити призначення",
     "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
+    "%1$s (renamed)" : "%1$s (перейменовано)",
+    "renamed file" : "перейменовано файл",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" є недозволеним ім'ям файлів або каталогів.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" є недозволеним префіксом у іменах файлів або каталоів.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" не дозволено всередині імени файлів або каталогів.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Налаштування",
     "Log out" : "Вихід",
     "Accounts" : "Облікові записи",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Переглянути %s в Bluesky",
     "Email" : "Електронна пошта",
     "Mail %s" : "Пошта %s",
     "Fediverse" : "Fediverse",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "Опис",
     "Display name" : "Ім'я для показу",
     "Headline" : "Заголовок",
-    "Organisation" : "Організація",
+    "Organization" : "Організація роботи",
     "Role" : "Роль",
     "Pronouns" : "Займенники",
     "Unknown account" : "Невідомий обліковий запис",
@@ -156,8 +160,8 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
     "Oracle Login and/or password not valid" : "Ім'я користувача та/або пароль Oracle не дійсні",
     "PostgreSQL Login and/or password not valid" : "Ім'я користувача та/або пароль PostgreSQL не дійсні",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X не підтримується, отже %s не працюватиме належним чиним на цій платформі. Використовуйте на ваш страх і ризик.",
-    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS не підтримується, %s не працюватиме коректно на цій платформі.",
+    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання сервера на базі GNU/Linux",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ймовірно, що сервер %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
     "Set an admin Login." : "Встановіть ім'я облікового запису адміністратора.",
@@ -201,15 +205,16 @@ OC.L10N.register(
     "Path is already shared with this group" : "Шлях вже надано у спільний доступ для цієї групи",
     "Link sharing is not allowed" : "Спільний доступ через посилання не дозволено",
     "Public upload is not allowed" : "Публічні завантаження не дозволено",
+    "You cannot share a folder that contains other shares" : "Неможливо надати у спільний доступ каталог, який вже містить інші спільні ресурси",
     "Sharing is disabled" : "Спільний доступ вимкнено",
     "Sharing is disabled for you" : "Ви не маєте права надавати у доступ файли або каталоги",
     "Cannot share with the share owner" : "Неможливо надавати у доступ власникові спільного ресурсу",
     "Share does not have a full ID" : "Спільний ресурс не має повного ідентифікатора",
     "Cannot change share type" : "Неможливо змінити тип спільного ресурсу",
     "Can only update recipient on user shares" : "Можна лише оновити отримувача для спільних ресурсів користувача",
-    "Cannot enable sending the password by Talk with an empty password" : "Не вдалося увімкнути надсилання паролю за допомогою Talk з порожнім паролем",
-    "Cannot enable sending the password by Talk without setting a new password" : "Не вдалося увімкнути надсилання паролю за допомогою Talk без встановлення нового паролю",
-    "Cannot disable sending the password by Talk without setting a new password" : "Не вдалося вимкнути надсилання паролю за допомогою Talk без встановлення нового паролю",
+    "Cannot enable sending the password by Talk with an empty password" : "Не вдалося увімкнути надсилання пароля за допомогою Talk з порожнім паролем",
+    "Cannot enable sending the password by Talk without setting a new password" : "Не вдалося увімкнути надсилання пароля за допомогою Talk без встановлення нового пароля",
+    "Cannot disable sending the password by Talk without setting a new password" : "Не вдалося вимкнути надсилання пароля за допомогою Talk без встановлення нового пароля",
     "Share provider does not support accepting" : "Провайдер спільного доступу не підтримує прийняття",
     "Cannot change target of link share" : "Неможливо змінити призначення для спільного ресурсу через посилання",
     "Invalid share recipient" : "Недійсний отримувач спільного ресурсу",
@@ -220,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
     "Input text" : "Текст для введення",
     "The input text" : "Текст для введення",
+    "Cannot generate more than 12 images" : "Можна зґенерувати не більше 12 зображень",
+    "Cannot generate less than 1 image" : "Зґенерувати можна не менше 1 зображення",
     "Sunday" : "Неділя",
     "Monday" : "Понеділок",
     "Tuesday" : "Вівторок",
@@ -272,23 +279,22 @@ OC.L10N.register(
     "A valid Login must be provided" : "Зазначте дійсне ім'я користувача",
     "Login contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу на початку або наприкінці",
     "Login must not consist of dots only" : "Ім'я користувача не може складатися лише з крапок",
+    "Username is too long" : "Ім'я користувача задовге",
     "Login is invalid because files already exist for this user" : "Недійсне ім'я облікового запису, оскільки файли для цього користувача вже присутні",
     "Account disabled" : "Обліковий запис вимкнено",
     "Login canceled by app" : "Вхід скасовано застосунком",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Застосунок \"%1$s\" неможливо встановити, оскільки не виконано такі залежності: %2$s",
     "a safe home for all your data" : "безпечна домівка для ваших даних",
     "Application is not enabled" : "Застосунок не увімкнено",
-    "Authentication error" : "Помилка авторизації",
+    "Authentication error" : "Помилка автентифікації",
     "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Не встановлено драйвер бази даних (sqlite, mysql, or postgresql).",
     "Cannot write into \"config\" directory." : "Не вдається записати в каталог \"config\".",
-    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації. Побачити %s",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Зазвичай це можна виправити шляхом надання вебсерверу доступу на запису до каталогу конфігурації. Докладно %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Або, якщо ви віддаєте перевагу файлу config.php лише для читання, встановіть для параметра \"config_is_read_only\" значення true. Побачити %s",
-    "Cannot write into \"apps\" directory." : "Відсутній доступ на запис до каталогу застосунків \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Зазвичай це можна виправити, якщо надати вебсерверу доступ для запису до каталогу застосунків або вимкнути App Store у конфігураційному файлі.",
     "Cannot create \"data\" directory." : "Неможливо створити каталог \"data\".",
-    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s",
-    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволи зазвичай можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s. ",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Зазвичай це можна виправити шляхом надання вебсерверу доступу на запис до кореневого каталогу. Докладно %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволи зазвичай можна виправити шляхом надання вебсерверу доступу на запис до кореневого каталогу. Докладно %s. ",
     "Your data directory is not writable." : "Ваш каталог даних не доступний для запису.",
     "Setting locale to %s failed." : "Помилка налаштування мови %s.",
     "Please install one of these locales on your system and restart your web server." : "Установіть одну з цих локалей у вашій системі та перезапустіть веб-сервер.",
@@ -296,8 +302,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Будь ласка, зверніться до адміністратора, щоб встановити модуль.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не встановлено в \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Налаштування цього параметра у php.ini змусить Nextcloud запуститися знову",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> замість <code>%s</code> очікуваного значення <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Щоб вирішити цю проблему, установіть для <code>mbstring.func_overload</code> значення <code>0</code> у вашому php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на обрізання блоків вбудованих документів. Це зробить кілька головних застосунків недоступними.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
@@ -311,7 +315,7 @@ OC.L10N.register(
     "Your data directory is invalid." : "Ваш каталог даних недійсний.",
     "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Перевірте, що в корені каталогу з даними присутній файл \"%1$s\". Він має містити: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "Дія \"%s\" не підтримується або не реалізована.",
-    "Authentication failed, wrong token or provider ID given" : "Помилка авторизації, надано неправильний токен або ідентифікатор постачальника",
+    "Authentication failed, wrong token or provider ID given" : "Помилка автентифікації, надано неправильний токен або ідентифікатор постачальника",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Немає параметрів для виконання запиту. Відсутні параметри: \"%s\"",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Ідентифікатор \"%1$s\" уже використовується постачальником об'єднаних хмар \"%2$s\"",
     "Cloud Federation Provider with ID: \"%s\" does not exist." : "Постачальник Cloud Federation з ідентифікатором \"%s\" не існує.",
@@ -322,47 +326,162 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Сховище тимчасово недоступне",
     "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Щоби дозволити запуск цієї перевірки, потрібно пересвідчитися, що ваш вебсервер може з'єднуватися з самим собою, що передбачає можливість резолвити та з'єднуватися з одним з `trusted_domains` або `overwrite.cli.url`. Неможливість цього може бути результатом незбігу DNS на стороні сервера або встановленими правилами брандмауера.",
+    "Analyze images" : "Аналізуйте зображення",
+    "Ask a question about the given images." : "Поставте запитання про наведені зображення.",
+    "Images" : "Зображення",
+    "Images to ask a question about" : "Зображення, про які можна задати питання",
+    "Question" : "Питання",
+    "What to ask about the images." : "Що запитати про зображення.",
+    "Generated response" : "Згенерована відповідь",
+    "The answer to the question" : "Відповідь на питання",
+    "Audio chat" : "Аудіо чат",
+    "Voice chat with the assistant" : "Голосовий чат з асистентом",
+    "System prompt" : "Системний запит",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Визначте правила та припущення, яких асистент повинен дотримуватися під час розмови.",
+    "Chat voice message" : "Голосове повідомлення в чаті",
+    "Describe a task that you want the assistant to do or ask a question." : "Опишіть завдання, яке ви хочете, щоб асистент виконав, або поставте запитання.",
+    "Chat history" : "Історія чату",
+    "The history of chat messages before the current message, starting with a message by the user." : "Історія повідомлень чату перед поточним повідомленням, починаючи з повідомлення користувача.",
+    "Input transcript" : "Вхідна стенограма",
+    "Transcription of the audio input" : "Транскрипція аудіовходу",
+    "Response voice message" : "Голосове повідомлення у відповідь",
+    "The generated voice response as part of the conversation" : "Згенерована голосова відповідь як частина розмови",
+    "Output transcript" : "Вихідна розшифровка",
+    "Transcription of the audio output" : "Транскрипція аудіовиходу",
     "Transcribe audio" : "Транскрибувати аудіо",
     "Transcribe the things said in an audio" : "Транскрибувати голос",
     "Audio input" : "Аудіовхід",
     "The audio to transcribe" : "Аудіо для транскрибування",
+    "Transcription" : "Транскрипція",
     "The transcribed text" : "Транскрибований текст",
+    "Chat by voice with an agent" : "Голосовий чат з агентом",
+    "Describe a task that you want the agent to do or ask a question." : "Опишіть завдання, яке ви хочете, щоб агент виконав, або поставте запитання.",
     "Confirmation" : "Підтвердження",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Чи підтверджувати раніше запитані дії: 0 для відмови та 1 для підтвердження.",
+    "Conversation token" : "Токен розмови",
+    "A token representing the conversation." : "Токен, що представляє розмову.",
+    "The new conversation token" : "Новий токен розмови",
+    "Send this along with the next interaction." : "Надішліть це разом з наступною взаємодією.",
+    "Requested actions by the agent" : "Необхідні дії агента",
+    "Actions that the agent would like to carry out in JSON format." : "Дії, які агент хотів би виконати у форматі JSON.",
+    "Chat with an agent" : "Чат з агентом",
+    "Chat message" : "Повідомлення в чаті",
+    "A chat message to send to the agent." : "Повідомлення в чаті для відправки агенту.",
+    "The response from the chat model." : "Відповідь від чат-моделі.",
+    "Context write" : "Контекстний запис",
+    "Writes text in a given style based on the provided source material." : "Пише текст у заданому стилі на основі наданого вихідного матеріалу.",
     "Writing style" : "Стиль письма",
+    "Demonstrate a writing style that you would like to immitate" : "Продемонструйте стиль письма, який ви хотіли б наслідувати",
+    "Source material" : "Вихідний матеріал",
+    "The content that would like to be rewritten in the new writing style" : "Контент, який хотілося б переписати в новому стилі",
     "Generated text" : "Зґенерований текст",
+    "The generated text with content from the source material in the given style" : "Згенерований текст з вмістом з вихідного матеріалу в заданому стилі",
     "Emoji generator" : "Ґенератор емоційок",
+    "Takes text and generates a representative emoji for it." : "Бере текст і генерує для нього відповідний емодзі.",
+    "The text to generate an emoji for" : "Текст для створення емодзі для",
     "Generated emoji" : "Зґенеровані емоційки",
+    "The generated emoji based on the input text" : "Згенеровані емодзі на основі введеного тексту",
+    "Optical character recognition" : "Оптичне розпізнавання символів",
+    "Extract text from files like images or PDFs" : "Видобути текст з файлів на кшталт зображення або PDF",
+    "Input files" : "Вхідні файли",
+    "The files to extract text from" : "Файли, з яких потрібно видобути текст",
+    "Output texts" : "Результуючі тексти",
+    "The texts that were extracted from the files" : "Текст, який було видобуто з файлів",
     "Generate image" : "Зґенерувати зображення",
+    "Generate an image from a text prompt" : "Створити зображення з текстової підказки",
     "Prompt" : "Запрошення",
+    "Describe the image you want to generate" : "Опишіть зображення, яке ви хочете створити",
+    "Number of images" : "Кількість зображень",
+    "How many images to generate" : "Скільки зображень генерувати",
+    "Output images" : "Вихідні зображення",
+    "The generated images" : "Згенеровані зображення",
+    "Generate speech" : "Генерування мовлення",
+    "Generate speech from a transcript" : "Створюйте мовлення з транскрипту",
+    "Write transcript that you want the assistant to generate speech from" : "Напишіть стенограму, з якої ви хочете, щоб асистент генерував мовлення",
+    "Output speech" : "Вихідне мовлення",
+    "The generated speech" : "Згенероване мовлення",
+    "Free text to text prompt" : "Безкоштовна підказка з тексту на текст",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Запускає довільний запит через мовну модель, яка повертає відповідь",
+    "Describe a task that you want the assistant to do or ask a question" : "Опишіть завдання, яке ви хочете, щоб асистент виконав, або поставте запитання",
+    "Generated reply" : "Згенерована відповідь",
+    "The generated text from the assistant" : "Згенерований текст від помічника",
+    "Change Tone" : "Змінити тон",
+    "Change the tone of a piece of text." : "Змініть тон фрагмента тексту.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Напишіть текст, який ви хочете, щоб асистент переписав в іншій тональності.",
+    "Desired tone" : "Бажаний тон",
+    "In which tone should your text be rewritten?" : "В якій тональності переписувати текст?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Переписаний текст у потрібній тональності, написаний асистентом:",
     "Chat" : "Чат",
+    "Chat with the assistant" : "Чат з асистентом",
+    "The history of chat messages before the current message, starting with a message by the user" : "Історія повідомлень чату перед поточним повідомленням, починаючи з повідомлення користувача",
+    "Response message" : "Відповідь",
+    "The generated response as part of the conversation" : "Згенерована відповідь як частина розмови",
+    "Chat with tools" : "Чат з інструментами",
+    "Chat with the language model with tool calling support." : "Чат з мовною моделлю з підтримкою виклику інструментів.",
+    "Tool message" : "Повідомлення про інструмент",
+    "The result of tool calls in the last interaction" : "Результат викликів інструментів в останній взаємодії",
+    "Available tools" : "Доступні інструменти",
+    "The available tools in JSON format" : "Доступні інструменти у форматі JSON",
+    "The response from the chat model" : "Відповідь від чат-моделі",
+    "Tool calls" : "Виклики інструментів",
+    "Tools call instructions from the model in JSON format" : "Інструменти викликають інструкції з моделі у форматі JSON",
+    "Formalize text" : "Формалізуйте текст",
+    "Takes a text and makes it sound more formal" : "Бере текст і робить його більш формальним",
+    "Write a text that you want the assistant to formalize" : "Напишіть текст, який ви хочете, щоб асистент оформив",
+    "Formalized text" : "Формалізований текст",
+    "The formalized text" : "Формалізований текст",
+    "Generate a headline" : "Створіть заголовок",
     "Generates a possible headline for a text." : "Створює ймовірний заголовок тексту.",
+    "Original text" : "Оригінальний текст",
+    "The original text to generate a headline for" : "Вихідний текст для створення заголовка для",
+    "The generated headline" : "Згенерований заголовок",
+    "Proofread" : "Вичитано",
+    "Proofreads a text and lists corrections" : "Вичитує текст і складає список виправлень",
     "Text" : "Текст",
+    "The text to proofread" : "Текст для вичитки",
+    "Corrections" : "Виправлення",
+    "The corrections that should be made in your text" : "Виправлення, які слід зробити у вашому тексті",
+    "Reformulate text" : "Переформатуйте текст",
+    "Takes a text and reformulates it" : "Бере текст і переформатовує його",
+    "Write a text that you want the assistant to reformulate" : "Напишіть текст, який ви хочете, щоб асистент переформулював",
+    "Reformulated text" : "Переформульований текст",
+    "The reformulated text, written by the assistant" : "Переформульований текст, написаний асистентом",
+    "Simplify text" : "Спростити текст",
+    "Takes a text and simplifies it" : "Бере текст і спрощує його",
+    "Write a text that you want the assistant to simplify" : "Напишіть текст, який ви хочете, щоб асистент спростив",
+    "Simplified text" : "Спрощений текст",
+    "The simplified text" : "Спрощений текст",
     "Summarize" : "Підсумок",
+    "Summarizes a text" : "Підсумовує текст",
+    "The original text to summarize" : "Оригінальний текст для підбиття підсумків",
     "Summary" : "Загалом",
+    "The generated summary" : "Згенерований підсумок",
     "Extract topics" : "Виділити теми",
+    "Extracts topics from a text and outputs them separated by commas" : "Витягує теми з тексту і виводить їх через кому",
+    "The original text to extract topics from" : "Оригінальний текст, з якого можна взяти теми",
+    "Topics" : "Теми",
+    "The list of extracted topics" : "Список витягнутих тем",
     "Translate" : "Перекласти",
+    "Translate text from one language to another" : "Перекладіть текст з однієї мови на іншу",
+    "Origin text" : "Вихідний текст",
+    "The text to translate" : "Текст для перекладу",
+    "Origin language" : "Мова походження",
+    "The language of the origin text" : "Мова оригінального тексту",
     "Target language" : "Цільова мова",
+    "The desired language to translate the origin text in" : "Бажана мова для перекладу вихідного тексту",
     "Result" : "Результат",
+    "The translated text" : "Перекладений текст",
     "Free prompt" : "Вільне запрошення",
     "Runs an arbitrary prompt through the language model." : "Виконує довільне запрошення через мовну модель.",
     "Generate headline" : "Створити заголовок",
     "Summarizes text by reducing its length without losing key information." : "Викокремлює головне у тексті шляхом зменшення довжини тексту без втрати ключової інформації.",
     "Extracts topics from a text and outputs them separated by commas." : "Виділяє теми, які висвітлює текст, зводить їх у перелік, що розділено комами.",
-    "Education Edition" : "Для навчання",
-    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
-    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
-    "File name is too long" : "Ім’я файлу занадто довге",
-    "Users" : "Користувачі",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати",
-    "»%s« added a note to a file shared with you" : "\"%s\" додано примітку до файлу у спільному доступі",
-    "Open »%s«" : "Відкрити %s",
-    "%1$s shared »%2$s« with you" : "%1$s надав(-ла) доступ до \"%2$s\"",
-    "%1$s shared »%2$s« with you." : "%1$s надав(-ла) доступ до \"%2$s\".",
-    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
-    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
-    "Cannot download file" : "Неможливо звантажити файл",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Переконайтеся, що в корені каталогу даних є файл під назвою \".ocdata\".",
-    "Path contains files shared with you" : "Шлях містить файли, якими поділилися з вами"
+    "Organisation" : "Організація",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X не підтримується, отже %s не працюватиме належним чиним на цій платформі. Використовуйте на ваш страх і ризик.",
+    "Login is too long" : "Ім'я користувача для авторизації задовге",
+    "Cannot write into \"apps\" directory." : "Відсутній доступ на запис до каталогу застосунків \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Зазвичай це можна виправити, якщо надати вебсерверу доступ для запису до каталогу застосунків або вимкнути App Store у конфігураційному файлі.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> замість <code>%s</code> очікуваного значення <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Щоб вирішити цю проблему, установіть для <code>mbstring.func_overload</code> значення <code>0</code> у вашому php.ini."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
